# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import billing_group_list_params, billing_group_create_params, billing_group_update_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.billing_group_list_response import BillingGroupListResponse
from ..types.billing_group_create_response import BillingGroupCreateResponse
from ..types.billing_group_delete_response import BillingGroupDeleteResponse
from ..types.billing_group_update_response import BillingGroupUpdateResponse
from ..types.billing_group_retrieve_response import BillingGroupRetrieveResponse

__all__ = ["BillingGroupsResource", "AsyncBillingGroupsResource"]


class BillingGroupsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> BillingGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return BillingGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BillingGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return BillingGroupsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupCreateResponse:
        """
        Create a billing group

        Args:
          name: A name for the billing group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/billing_groups",
            body=maybe_transform({"name": name}, billing_group_create_params.BillingGroupCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupRetrieveResponse:
        """
        Get a billing group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/billing_groups/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupRetrieveResponse,
        )

    def update(
        self,
        id: str,
        *,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupUpdateResponse:
        """
        Update a billing group

        Args:
          name: A name for the billing group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._patch(
            f"/billing_groups/{id}",
            body=maybe_transform({"name": name}, billing_group_update_params.BillingGroupUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupUpdateResponse,
        )

    def list(
        self,
        *,
        page: billing_group_list_params.Page | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupListResponse:
        """
        List all billing groups

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/billing_groups",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"page": page}, billing_group_list_params.BillingGroupListParams),
            ),
            cast_to=BillingGroupListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupDeleteResponse:
        """
        Delete a billing group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/billing_groups/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupDeleteResponse,
        )


class AsyncBillingGroupsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncBillingGroupsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncBillingGroupsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBillingGroupsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncBillingGroupsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupCreateResponse:
        """
        Create a billing group

        Args:
          name: A name for the billing group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/billing_groups",
            body=await async_maybe_transform({"name": name}, billing_group_create_params.BillingGroupCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupRetrieveResponse:
        """
        Get a billing group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/billing_groups/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupRetrieveResponse,
        )

    async def update(
        self,
        id: str,
        *,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupUpdateResponse:
        """
        Update a billing group

        Args:
          name: A name for the billing group

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._patch(
            f"/billing_groups/{id}",
            body=await async_maybe_transform({"name": name}, billing_group_update_params.BillingGroupUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupUpdateResponse,
        )

    async def list(
        self,
        *,
        page: billing_group_list_params.Page | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupListResponse:
        """
        List all billing groups

        Args:
          page: Consolidated page parameter (deepObject style). Originally: page[number],
              page[size]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/billing_groups",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"page": page}, billing_group_list_params.BillingGroupListParams),
            ),
            cast_to=BillingGroupListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BillingGroupDeleteResponse:
        """
        Delete a billing group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/billing_groups/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BillingGroupDeleteResponse,
        )


class BillingGroupsResourceWithRawResponse:
    def __init__(self, billing_groups: BillingGroupsResource) -> None:
        self._billing_groups = billing_groups

        self.create = to_raw_response_wrapper(
            billing_groups.create,
        )
        self.retrieve = to_raw_response_wrapper(
            billing_groups.retrieve,
        )
        self.update = to_raw_response_wrapper(
            billing_groups.update,
        )
        self.list = to_raw_response_wrapper(
            billing_groups.list,
        )
        self.delete = to_raw_response_wrapper(
            billing_groups.delete,
        )


class AsyncBillingGroupsResourceWithRawResponse:
    def __init__(self, billing_groups: AsyncBillingGroupsResource) -> None:
        self._billing_groups = billing_groups

        self.create = async_to_raw_response_wrapper(
            billing_groups.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            billing_groups.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            billing_groups.update,
        )
        self.list = async_to_raw_response_wrapper(
            billing_groups.list,
        )
        self.delete = async_to_raw_response_wrapper(
            billing_groups.delete,
        )


class BillingGroupsResourceWithStreamingResponse:
    def __init__(self, billing_groups: BillingGroupsResource) -> None:
        self._billing_groups = billing_groups

        self.create = to_streamed_response_wrapper(
            billing_groups.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            billing_groups.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            billing_groups.update,
        )
        self.list = to_streamed_response_wrapper(
            billing_groups.list,
        )
        self.delete = to_streamed_response_wrapper(
            billing_groups.delete,
        )


class AsyncBillingGroupsResourceWithStreamingResponse:
    def __init__(self, billing_groups: AsyncBillingGroupsResource) -> None:
        self._billing_groups = billing_groups

        self.create = async_to_streamed_response_wrapper(
            billing_groups.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            billing_groups.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            billing_groups.update,
        )
        self.list = async_to_streamed_response_wrapper(
            billing_groups.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            billing_groups.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel
from .external_connection_phone_number import ExternalConnectionPhoneNumber
from ..external_voice_integrations_pagination_meta import ExternalVoiceIntegrationsPaginationMeta

__all__ = ["PhoneNumberListResponse"]


class PhoneNumberListResponse(BaseModel):
    data: Optional[List[ExternalConnectionPhoneNumber]] = None

    meta: Optional[ExternalVoiceIntegrationsPaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["ExternalConnectionListParams", "Filter", "FilterConnectionName", "FilterPhoneNumber", "Page"]


class ExternalConnectionListParams(TypedDict, total=False):
    filter: Filter
    """Filter parameter for external connections (deepObject style).

    Supports filtering by connection_name, external_sip_connection, id, created_at,
    and phone_number.
    """

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """


class FilterConnectionName(TypedDict, total=False):
    contains: str
    """
    If present, connections with <code>connection_name</code> containing the given
    value will be returned. Matching is not case-sensitive. Requires at least three
    characters.
    """


class FilterPhoneNumber(TypedDict, total=False):
    contains: str
    """If present, connections associated with the given phone_number will be returned.

    A full match is necessary with a e164 format.
    """


class Filter(TypedDict, total=False):
    id: str
    """
    If present, connections with <code>id</code> matching the given value will be
    returned.
    """

    connection_name: FilterConnectionName

    created_at: str
    """
    If present, connections with <code>created_at</code> date matching the given
    YYYY-MM-DD date will be returned.
    """

    external_sip_connection: Literal["zoom", "operator_connect"]
    """
    If present, connections with <code>external_sip_connection</code> matching the
    given value will be returned.
    """

    phone_number: FilterPhoneNumber
    """Phone number filter for connections.

    Note: Despite the 'contains' name, this requires a full E164 match per the
    original specification.
    """


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel
from .pagination_meta import PaginationMeta

__all__ = ["ChannelZoneListResponse", "Data"]


class Data(BaseModel):
    id: str

    channels: int

    countries: List[str]
    """
    List of countries (in ISO 3166-2, capitalized) members of the billing channel
    zone
    """

    name: str

    record_type: Literal["channel_zone"]

    created_at: Optional[str] = None
    """ISO 8601 formatted date of when the channel zone was created"""

    updated_at: Optional[str] = None
    """ISO 8601 formatted date of when the channel zone was updated"""


class ChannelZoneListResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ai import (
    AIResource,
    AsyncAIResource,
    AIResourceWithRawResponse,
    AsyncAIResourceWithRawResponse,
    AIResourceWithStreamingResponse,
    AsyncAIResourceWithStreamingResponse,
)
from .ips import (
    IPsResource,
    AsyncIPsResource,
    IPsResourceWithRawResponse,
    AsyncIPsResourceWithRawResponse,
    IPsResourceWithStreamingResponse,
    AsyncIPsResourceWithStreamingResponse,
)
from .enum import (
    EnumResource,
    AsyncEnumResource,
    EnumResourceWithRawResponse,
    AsyncEnumResourceWithRawResponse,
    EnumResourceWithStreamingResponse,
    AsyncEnumResourceWithStreamingResponse,
)
from .list import (
    ListResource,
    AsyncListResource,
    ListResourceWithRawResponse,
    AsyncListResourceWithRawResponse,
    ListResourceWithStreamingResponse,
    AsyncListResourceWithStreamingResponse,
)
from .seti import (
    SetiResource,
    AsyncSetiResource,
    SetiResourceWithRawResponse,
    AsyncSetiResourceWithRawResponse,
    SetiResourceWithStreamingResponse,
    AsyncSetiResourceWithStreamingResponse,
)
from .brand import (
    BrandResource,
    AsyncBrandResource,
    BrandResourceWithRawResponse,
    AsyncBrandResourceWithRawResponse,
    BrandResourceWithStreamingResponse,
    AsyncBrandResourceWithStreamingResponse,
)
from .calls import (
    CallsResource,
    AsyncCallsResource,
    CallsResourceWithRawResponse,
    AsyncCallsResourceWithRawResponse,
    CallsResourceWithStreamingResponse,
    AsyncCallsResourceWithStreamingResponse,
)
from .faxes import (
    FaxesResource,
    AsyncFaxesResource,
    FaxesResourceWithRawResponse,
    AsyncFaxesResourceWithRawResponse,
    FaxesResourceWithStreamingResponse,
    AsyncFaxesResourceWithStreamingResponse,
)
from .fqdns import (
    FqdnsResource,
    AsyncFqdnsResource,
    FqdnsResourceWithRawResponse,
    AsyncFqdnsResourceWithRawResponse,
    FqdnsResourceWithStreamingResponse,
    AsyncFqdnsResourceWithStreamingResponse,
)
from .media import (
    MediaResource,
    AsyncMediaResource,
    MediaResourceWithRawResponse,
    AsyncMediaResourceWithRawResponse,
    MediaResourceWithStreamingResponse,
    AsyncMediaResourceWithStreamingResponse,
)
from .oauth import (
    OAuthResource,
    AsyncOAuthResource,
    OAuthResourceWithRawResponse,
    AsyncOAuthResourceWithRawResponse,
    OAuthResourceWithStreamingResponse,
    AsyncOAuthResourceWithStreamingResponse,
)
from .rooms import (
    RoomsResource,
    AsyncRoomsResource,
    RoomsResourceWithRawResponse,
    AsyncRoomsResourceWithRawResponse,
    RoomsResourceWithStreamingResponse,
    AsyncRoomsResourceWithStreamingResponse,
)
from .texml import (
    TexmlResource,
    AsyncTexmlResource,
    TexmlResourceWithRawResponse,
    AsyncTexmlResourceWithRawResponse,
    TexmlResourceWithStreamingResponse,
    AsyncTexmlResourceWithStreamingResponse,
)
from .legacy import (
    LegacyResource,
    AsyncLegacyResource,
    LegacyResourceWithRawResponse,
    AsyncLegacyResourceWithRawResponse,
    LegacyResourceWithStreamingResponse,
    AsyncLegacyResourceWithStreamingResponse,
)
from .queues import (
    QueuesResource,
    AsyncQueuesResource,
    QueuesResourceWithRawResponse,
    AsyncQueuesResourceWithRawResponse,
    QueuesResourceWithStreamingResponse,
    AsyncQueuesResourceWithStreamingResponse,
)
from .actions import (
    ActionsResource,
    AsyncActionsResource,
    ActionsResourceWithRawResponse,
    AsyncActionsResourceWithRawResponse,
    ActionsResourceWithStreamingResponse,
    AsyncActionsResourceWithStreamingResponse,
)
from .balance import (
    BalanceResource,
    AsyncBalanceResource,
    BalanceResourceWithRawResponse,
    AsyncBalanceResourceWithRawResponse,
    BalanceResourceWithStreamingResponse,
    AsyncBalanceResourceWithStreamingResponse,
)
from .payment import (
    PaymentResource,
    AsyncPaymentResource,
    PaymentResourceWithRawResponse,
    AsyncPaymentResourceWithRawResponse,
    PaymentResourceWithStreamingResponse,
    AsyncPaymentResourceWithStreamingResponse,
)
from .porting import (
    PortingResource,
    AsyncPortingResource,
    PortingResourceWithRawResponse,
    AsyncPortingResourceWithRawResponse,
    PortingResourceWithStreamingResponse,
    AsyncPortingResourceWithStreamingResponse,
)
from .regions import (
    RegionsResource,
    AsyncRegionsResource,
    RegionsResourceWithRawResponse,
    AsyncRegionsResourceWithRawResponse,
    RegionsResourceWithStreamingResponse,
    AsyncRegionsResourceWithStreamingResponse,
)
from .reports import (
    ReportsResource,
    AsyncReportsResource,
    ReportsResourceWithRawResponse,
    AsyncReportsResourceWithRawResponse,
    ReportsResourceWithStreamingResponse,
    AsyncReportsResourceWithStreamingResponse,
)
from .storage import (
    StorageResource,
    AsyncStorageResource,
    StorageResourceWithRawResponse,
    AsyncStorageResourceWithRawResponse,
    StorageResourceWithStreamingResponse,
    AsyncStorageResourceWithStreamingResponse,
)
from .campaign import (
    CampaignResource,
    AsyncCampaignResource,
    CampaignResourceWithRawResponse,
    AsyncCampaignResourceWithRawResponse,
    CampaignResourceWithStreamingResponse,
    AsyncCampaignResourceWithStreamingResponse,
)
from .comments import (
    CommentsResource,
    AsyncCommentsResource,
    CommentsResourceWithRawResponse,
    AsyncCommentsResourceWithRawResponse,
    CommentsResourceWithStreamingResponse,
    AsyncCommentsResourceWithStreamingResponse,
)
from .invoices import (
    InvoicesResource,
    AsyncInvoicesResource,
    InvoicesResourceWithRawResponse,
    AsyncInvoicesResourceWithRawResponse,
    InvoicesResourceWithStreamingResponse,
    AsyncInvoicesResourceWithStreamingResponse,
)
from .messages import (
    MessagesResource,
    AsyncMessagesResource,
    MessagesResourceWithRawResponse,
    AsyncMessagesResourceWithRawResponse,
    MessagesResourceWithStreamingResponse,
    AsyncMessagesResourceWithStreamingResponse,
)
from .networks import (
    NetworksResource,
    AsyncNetworksResource,
    NetworksResourceWithRawResponse,
    AsyncNetworksResourceWithRawResponse,
    NetworksResourceWithStreamingResponse,
    AsyncNetworksResourceWithStreamingResponse,
)
from .portouts import (
    PortoutsResource,
    AsyncPortoutsResource,
    PortoutsResourceWithRawResponse,
    AsyncPortoutsResourceWithRawResponse,
    PortoutsResourceWithStreamingResponse,
    AsyncPortoutsResourceWithStreamingResponse,
)
from .webhooks import TelnyxWebhook, WebhooksResource, AsyncWebhooksResource, TelnyxWebhookVerificationError
from .wireless import (
    WirelessResource,
    AsyncWirelessResource,
    WirelessResourceWithRawResponse,
    AsyncWirelessResourceWithRawResponse,
    WirelessResourceWithStreamingResponse,
    AsyncWirelessResourceWithStreamingResponse,
)
from .addresses import (
    AddressesResource,
    AsyncAddressesResource,
    AddressesResourceWithRawResponse,
    AsyncAddressesResourceWithRawResponse,
    AddressesResourceWithStreamingResponse,
    AsyncAddressesResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)
from .messaging import (
    MessagingResource,
    AsyncMessagingResource,
    MessagingResourceWithRawResponse,
    AsyncMessagingResourceWithRawResponse,
    MessagingResourceWithStreamingResponse,
    AsyncMessagingResourceWithStreamingResponse,
)
from .messsages import (
    MesssagesResource,
    AsyncMesssagesResource,
    MesssagesResourceWithRawResponse,
    AsyncMesssagesResourceWithRawResponse,
    MesssagesResourceWithStreamingResponse,
    AsyncMesssagesResourceWithStreamingResponse,
)
from .sim_cards import (
    SimCardsResource,
    AsyncSimCardsResource,
    SimCardsResourceWithRawResponse,
    AsyncSimCardsResourceWithRawResponse,
    SimCardsResourceWithStreamingResponse,
    AsyncSimCardsResourceWithStreamingResponse,
)
from .user_tags import (
    UserTagsResource,
    AsyncUserTagsResource,
    UserTagsResourceWithRawResponse,
    AsyncUserTagsResourceWithRawResponse,
    UserTagsResourceWithStreamingResponse,
    AsyncUserTagsResourceWithStreamingResponse,
)
from .global_ips import (
    GlobalIPsResource,
    AsyncGlobalIPsResource,
    GlobalIPsResourceWithRawResponse,
    AsyncGlobalIPsResourceWithRawResponse,
    GlobalIPsResourceWithStreamingResponse,
    AsyncGlobalIPsResourceWithStreamingResponse,
)
from .recordings import (
    RecordingsResource,
    AsyncRecordingsResource,
    RecordingsResourceWithRawResponse,
    AsyncRecordingsResourceWithRawResponse,
    RecordingsResourceWithStreamingResponse,
    AsyncRecordingsResourceWithStreamingResponse,
)
from .well_known import (
    WellKnownResource,
    AsyncWellKnownResource,
    WellKnownResourceWithRawResponse,
    AsyncWellKnownResourceWithRawResponse,
    WellKnownResourceWithStreamingResponse,
    AsyncWellKnownResourceWithStreamingResponse,
)
from .call_events import (
    CallEventsResource,
    AsyncCallEventsResource,
    CallEventsResourceWithRawResponse,
    AsyncCallEventsResourceWithRawResponse,
    CallEventsResourceWithStreamingResponse,
    AsyncCallEventsResourceWithStreamingResponse,
)
from .conferences import (
    ConferencesResource,
    AsyncConferencesResource,
    ConferencesResourceWithRawResponse,
    AsyncConferencesResourceWithRawResponse,
    ConferencesResourceWithStreamingResponse,
    AsyncConferencesResourceWithStreamingResponse,
)
from .connections import (
    ConnectionsResource,
    AsyncConnectionsResource,
    ConnectionsResourceWithRawResponse,
    AsyncConnectionsResourceWithRawResponse,
    ConnectionsResourceWithStreamingResponse,
    AsyncConnectionsResourceWithStreamingResponse,
)
from .ota_updates import (
    OtaUpdatesResource,
    AsyncOtaUpdatesResource,
    OtaUpdatesResourceWithRawResponse,
    AsyncOtaUpdatesResourceWithRawResponse,
    OtaUpdatesResourceWithStreamingResponse,
    AsyncOtaUpdatesResourceWithStreamingResponse,
)
from .short_codes import (
    ShortCodesResource,
    AsyncShortCodesResource,
    ShortCodesResourceWithRawResponse,
    AsyncShortCodesResourceWithRawResponse,
    ShortCodesResourceWithStreamingResponse,
    AsyncShortCodesResourceWithStreamingResponse,
)
from .audit_events import (
    AuditEventsResource,
    AsyncAuditEventsResource,
    AuditEventsResourceWithRawResponse,
    AsyncAuditEventsResourceWithRawResponse,
    AuditEventsResourceWithStreamingResponse,
    AsyncAuditEventsResourceWithStreamingResponse,
)
from .oauth_grants import (
    OAuthGrantsResource,
    AsyncOAuthGrantsResource,
    OAuthGrantsResourceWithRawResponse,
    AsyncOAuthGrantsResourceWithRawResponse,
    OAuthGrantsResourceWithStreamingResponse,
    AsyncOAuthGrantsResourceWithStreamingResponse,
)
from .requirements import (
    RequirementsResource,
    AsyncRequirementsResource,
    RequirementsResourceWithRawResponse,
    AsyncRequirementsResourceWithRawResponse,
    RequirementsResourceWithStreamingResponse,
    AsyncRequirementsResourceWithStreamingResponse,
)
from .channel_zones import (
    ChannelZonesResource,
    AsyncChannelZonesResource,
    ChannelZonesResourceWithRawResponse,
    AsyncChannelZonesResourceWithRawResponse,
    ChannelZonesResourceWithStreamingResponse,
    AsyncChannelZonesResourceWithStreamingResponse,
)
from .number_lookup import (
    NumberLookupResource,
    AsyncNumberLookupResource,
    NumberLookupResourceWithRawResponse,
    AsyncNumberLookupResourceWithRawResponse,
    NumberLookupResourceWithStreamingResponse,
    AsyncNumberLookupResourceWithStreamingResponse,
)
from .number_orders import (
    NumberOrdersResource,
    AsyncNumberOrdersResource,
    NumberOrdersResourceWithRawResponse,
    AsyncNumberOrdersResourceWithRawResponse,
    NumberOrdersResourceWithStreamingResponse,
    AsyncNumberOrdersResourceWithStreamingResponse,
)
from .oauth_clients import (
    OAuthClientsResource,
    AsyncOAuthClientsResource,
    OAuthClientsResourceWithRawResponse,
    AsyncOAuthClientsResourceWithRawResponse,
    OAuthClientsResourceWithStreamingResponse,
    AsyncOAuthClientsResourceWithStreamingResponse,
)
from .phone_numbers import (
    PhoneNumbersResource,
    AsyncPhoneNumbersResource,
    PhoneNumbersResourceWithRawResponse,
    AsyncPhoneNumbersResourceWithRawResponse,
    PhoneNumbersResourceWithStreamingResponse,
    AsyncPhoneNumbersResourceWithStreamingResponse,
)
from .usage_reports import (
    UsageReportsResource,
    AsyncUsageReportsResource,
    UsageReportsResourceWithRawResponse,
    AsyncUsageReportsResourceWithRawResponse,
    UsageReportsResourceWithStreamingResponse,
    AsyncUsageReportsResourceWithStreamingResponse,
)
from .verifications import (
    VerificationsResource,
    AsyncVerificationsResource,
    VerificationsResourceWithRawResponse,
    AsyncVerificationsResourceWithRawResponse,
    VerificationsResourceWithStreamingResponse,
    AsyncVerificationsResourceWithStreamingResponse,
)
from .billing_groups import (
    BillingGroupsResource,
    AsyncBillingGroupsResource,
    BillingGroupsResourceWithRawResponse,
    AsyncBillingGroupsResourceWithRawResponse,
    BillingGroupsResourceWithStreamingResponse,
    AsyncBillingGroupsResourceWithStreamingResponse,
)
from .bundle_pricing import (
    BundlePricingResource,
    AsyncBundlePricingResource,
    BundlePricingResourceWithRawResponse,
    AsyncBundlePricingResourceWithRawResponse,
    BundlePricingResourceWithStreamingResponse,
    AsyncBundlePricingResourceWithStreamingResponse,
)
from .detail_records import (
    DetailRecordsResource,
    AsyncDetailRecordsResource,
    DetailRecordsResourceWithRawResponse,
    AsyncDetailRecordsResourceWithRawResponse,
    DetailRecordsResourceWithStreamingResponse,
    AsyncDetailRecordsResourceWithStreamingResponse,
)
from .document_links import (
    DocumentLinksResource,
    AsyncDocumentLinksResource,
    DocumentLinksResourceWithRawResponse,
    AsyncDocumentLinksResourceWithRawResponse,
    DocumentLinksResourceWithStreamingResponse,
    AsyncDocumentLinksResourceWithStreamingResponse,
)
from .ip_connections import (
    IPConnectionsResource,
    AsyncIPConnectionsResource,
    IPConnectionsResourceWithRawResponse,
    AsyncIPConnectionsResourceWithRawResponse,
    IPConnectionsResourceWithStreamingResponse,
    AsyncIPConnectionsResourceWithStreamingResponse,
)
from .porting_orders import (
    PortingOrdersResource,
    AsyncPortingOrdersResource,
    PortingOrdersResourceWithRawResponse,
    AsyncPortingOrdersResourceWithRawResponse,
    PortingOrdersResourceWithStreamingResponse,
    AsyncPortingOrdersResourceWithStreamingResponse,
)
from .text_to_speech import (
    TextToSpeechResource,
    AsyncTextToSpeechResource,
    TextToSpeechResourceWithRawResponse,
    AsyncTextToSpeechResourceWithRawResponse,
    TextToSpeechResourceWithStreamingResponse,
    AsyncTextToSpeechResourceWithStreamingResponse,
)
from .user_addresses import (
    UserAddressesResource,
    AsyncUserAddressesResource,
    UserAddressesResourceWithRawResponse,
    AsyncUserAddressesResourceWithRawResponse,
    UserAddressesResourceWithStreamingResponse,
    AsyncUserAddressesResourceWithStreamingResponse,
)
from .advanced_orders import (
    AdvancedOrdersResource,
    AsyncAdvancedOrdersResource,
    AdvancedOrdersResourceWithRawResponse,
    AsyncAdvancedOrdersResourceWithRawResponse,
    AdvancedOrdersResourceWithStreamingResponse,
    AsyncAdvancedOrdersResourceWithStreamingResponse,
)
from .charges_summary import (
    ChargesSummaryResource,
    AsyncChargesSummaryResource,
    ChargesSummaryResourceWithRawResponse,
    AsyncChargesSummaryResourceWithRawResponse,
    ChargesSummaryResourceWithStreamingResponse,
    AsyncChargesSummaryResourceWithStreamingResponse,
)
from .global_ip_usage import (
    GlobalIPUsageResource,
    AsyncGlobalIPUsageResource,
    GlobalIPUsageResourceWithRawResponse,
    AsyncGlobalIPUsageResourceWithRawResponse,
    GlobalIPUsageResourceWithStreamingResponse,
    AsyncGlobalIPUsageResourceWithStreamingResponse,
)
from .room_recordings import (
    RoomRecordingsResource,
    AsyncRoomRecordingsResource,
    RoomRecordingsResourceWithRawResponse,
    AsyncRoomRecordingsResourceWithRawResponse,
    RoomRecordingsResourceWithStreamingResponse,
    AsyncRoomRecordingsResourceWithStreamingResponse,
)
from .sim_card_groups import (
    SimCardGroupsResource,
    AsyncSimCardGroupsResource,
    SimCardGroupsResourceWithRawResponse,
    AsyncSimCardGroupsResourceWithRawResponse,
    SimCardGroupsResourceWithStreamingResponse,
    AsyncSimCardGroupsResourceWithStreamingResponse,
)
from .sim_card_orders import (
    SimCardOrdersResource,
    AsyncSimCardOrdersResource,
    SimCardOrdersResourceWithRawResponse,
    AsyncSimCardOrdersResourceWithRawResponse,
    SimCardOrdersResourceWithStreamingResponse,
    AsyncSimCardOrdersResourceWithStreamingResponse,
)
from .verify_profiles import (
    VerifyProfilesResource,
    AsyncVerifyProfilesResource,
    VerifyProfilesResourceWithRawResponse,
    AsyncVerifyProfilesResourceWithRawResponse,
    VerifyProfilesResourceWithStreamingResponse,
    AsyncVerifyProfilesResourceWithStreamingResponse,
)
from .wireguard_peers import (
    WireguardPeersResource,
    AsyncWireguardPeersResource,
    WireguardPeersResourceWithRawResponse,
    AsyncWireguardPeersResourceWithRawResponse,
    WireguardPeersResourceWithStreamingResponse,
    AsyncWireguardPeersResourceWithStreamingResponse,
)
from .access_ip_ranges import (
    AccessIPRangesResource,
    AsyncAccessIPRangesResource,
    AccessIPRangesResourceWithRawResponse,
    AsyncAccessIPRangesResourceWithRawResponse,
    AccessIPRangesResourceWithStreamingResponse,
    AsyncAccessIPRangesResourceWithStreamingResponse,
)
from .campaign_builder import (
    CampaignBuilderResource,
    AsyncCampaignBuilderResource,
    CampaignBuilderResourceWithRawResponse,
    AsyncCampaignBuilderResourceWithRawResponse,
    CampaignBuilderResourceWithStreamingResponse,
    AsyncCampaignBuilderResourceWithStreamingResponse,
)
from .country_coverage import (
    CountryCoverageResource,
    AsyncCountryCoverageResource,
    CountryCoverageResourceWithRawResponse,
    AsyncCountryCoverageResourceWithRawResponse,
    CountryCoverageResourceWithStreamingResponse,
    AsyncCountryCoverageResourceWithStreamingResponse,
)
from .fax_applications import (
    FaxApplicationsResource,
    AsyncFaxApplicationsResource,
    FaxApplicationsResourceWithRawResponse,
    AsyncFaxApplicationsResourceWithRawResponse,
    FaxApplicationsResourceWithStreamingResponse,
    AsyncFaxApplicationsResourceWithStreamingResponse,
)
from .fqdn_connections import (
    FqdnConnectionsResource,
    AsyncFqdnConnectionsResource,
    FqdnConnectionsResourceWithRawResponse,
    AsyncFqdnConnectionsResourceWithRawResponse,
    FqdnConnectionsResourceWithStreamingResponse,
    AsyncFqdnConnectionsResourceWithStreamingResponse,
)
from .inbound_channels import (
    InboundChannelsResource,
    AsyncInboundChannelsResource,
    InboundChannelsResourceWithRawResponse,
    AsyncInboundChannelsResourceWithRawResponse,
    InboundChannelsResourceWithStreamingResponse,
    AsyncInboundChannelsResourceWithStreamingResponse,
)
from .managed_accounts import (
    ManagedAccountsResource,
    AsyncManagedAccountsResource,
    ManagedAccountsResourceWithRawResponse,
    AsyncManagedAccountsResourceWithRawResponse,
    ManagedAccountsResourceWithStreamingResponse,
    AsyncManagedAccountsResourceWithStreamingResponse,
)
from .network_coverage import (
    NetworkCoverageResource,
    AsyncNetworkCoverageResource,
    NetworkCoverageResourceWithRawResponse,
    AsyncNetworkCoverageResourceWithRawResponse,
    NetworkCoverageResourceWithStreamingResponse,
    AsyncNetworkCoverageResourceWithStreamingResponse,
)
from .numbers_features import (
    NumbersFeaturesResource,
    AsyncNumbersFeaturesResource,
    NumbersFeaturesResourceWithRawResponse,
    AsyncNumbersFeaturesResourceWithRawResponse,
    NumbersFeaturesResourceWithStreamingResponse,
    AsyncNumbersFeaturesResourceWithStreamingResponse,
)
from .operator_connect import (
    OperatorConnectResource,
    AsyncOperatorConnectResource,
    OperatorConnectResourceWithRawResponse,
    AsyncOperatorConnectResourceWithRawResponse,
    OperatorConnectResourceWithStreamingResponse,
    AsyncOperatorConnectResourceWithStreamingResponse,
)
from .verified_numbers import (
    VerifiedNumbersResource,
    AsyncVerifiedNumbersResource,
    VerifiedNumbersResourceWithRawResponse,
    AsyncVerifiedNumbersResourceWithRawResponse,
    VerifiedNumbersResourceWithStreamingResponse,
    AsyncVerifiedNumbersResourceWithStreamingResponse,
)
from .access_ip_address import (
    AccessIPAddressResource,
    AsyncAccessIPAddressResource,
    AccessIPAddressResourceWithRawResponse,
    AsyncAccessIPAddressResourceWithRawResponse,
    AccessIPAddressResourceWithStreamingResponse,
    AsyncAccessIPAddressResourceWithStreamingResponse,
)
from .charges_breakdown import (
    ChargesBreakdownResource,
    AsyncChargesBreakdownResource,
    ChargesBreakdownResourceWithRawResponse,
    AsyncChargesBreakdownResourceWithRawResponse,
    ChargesBreakdownResourceWithStreamingResponse,
    AsyncChargesBreakdownResourceWithStreamingResponse,
)
from .global_ip_latency import (
    GlobalIPLatencyResource,
    AsyncGlobalIPLatencyResource,
    GlobalIPLatencyResourceWithRawResponse,
    AsyncGlobalIPLatencyResourceWithRawResponse,
    GlobalIPLatencyResourceWithStreamingResponse,
    AsyncGlobalIPLatencyResourceWithStreamingResponse,
)
from .messaging_optouts import (
    MessagingOptoutsResource,
    AsyncMessagingOptoutsResource,
    MessagingOptoutsResourceWithRawResponse,
    AsyncMessagingOptoutsResourceWithRawResponse,
    MessagingOptoutsResourceWithStreamingResponse,
    AsyncMessagingOptoutsResourceWithStreamingResponse,
)
from .partner_campaigns import (
    PartnerCampaignsResource,
    AsyncPartnerCampaignsResource,
    PartnerCampaignsResourceWithRawResponse,
    AsyncPartnerCampaignsResourceWithRawResponse,
    PartnerCampaignsResourceWithStreamingResponse,
    AsyncPartnerCampaignsResourceWithStreamingResponse,
)
from .requirement_types import (
    RequirementTypesResource,
    AsyncRequirementTypesResource,
    RequirementTypesResourceWithRawResponse,
    AsyncRequirementTypesResourceWithRawResponse,
    RequirementTypesResourceWithStreamingResponse,
    AsyncRequirementTypesResourceWithStreamingResponse,
)
from .room_compositions import (
    RoomCompositionsResource,
    AsyncRoomCompositionsResource,
    RoomCompositionsResourceWithRawResponse,
    AsyncRoomCompositionsResourceWithRawResponse,
    RoomCompositionsResourceWithStreamingResponse,
    AsyncRoomCompositionsResourceWithStreamingResponse,
)
from .room_participants import (
    RoomParticipantsResource,
    AsyncRoomParticipantsResource,
    RoomParticipantsResourceWithRawResponse,
    AsyncRoomParticipantsResourceWithRawResponse,
    RoomParticipantsResourceWithStreamingResponse,
    AsyncRoomParticipantsResourceWithStreamingResponse,
)
from .siprec_connectors import (
    SiprecConnectorsResource,
    AsyncSiprecConnectorsResource,
    SiprecConnectorsResourceWithRawResponse,
    AsyncSiprecConnectorsResourceWithRawResponse,
    SiprecConnectorsResourceWithStreamingResponse,
    AsyncSiprecConnectorsResourceWithStreamingResponse,
)
from .sub_number_orders import (
    SubNumberOrdersResource,
    AsyncSubNumberOrdersResource,
    SubNumberOrdersResourceWithRawResponse,
    AsyncSubNumberOrdersResourceWithRawResponse,
    SubNumberOrdersResourceWithStreamingResponse,
    AsyncSubNumberOrdersResourceWithStreamingResponse,
)
from .inventory_coverage import (
    InventoryCoverageResource,
    AsyncInventoryCoverageResource,
    InventoryCoverageResourceWithRawResponse,
    AsyncInventoryCoverageResourceWithRawResponse,
    InventoryCoverageResourceWithStreamingResponse,
    AsyncInventoryCoverageResourceWithStreamingResponse,
)
from .messaging_profiles import (
    MessagingProfilesResource,
    AsyncMessagingProfilesResource,
    MessagingProfilesResourceWithRawResponse,
    AsyncMessagingProfilesResourceWithRawResponse,
    MessagingProfilesResourceWithStreamingResponse,
    AsyncMessagingProfilesResourceWithStreamingResponse,
)
from .messaging_tollfree import (
    MessagingTollfreeResource,
    AsyncMessagingTollfreeResource,
    MessagingTollfreeResourceWithRawResponse,
    AsyncMessagingTollfreeResourceWithRawResponse,
    MessagingTollfreeResourceWithStreamingResponse,
    AsyncMessagingTollfreeResourceWithStreamingResponse,
)
from .portability_checks import (
    PortabilityChecksResource,
    AsyncPortabilityChecksResource,
    PortabilityChecksResourceWithRawResponse,
    AsyncPortabilityChecksResourceWithRawResponse,
    PortabilityChecksResourceWithStreamingResponse,
    AsyncPortabilityChecksResourceWithStreamingResponse,
)
from .requirement_groups import (
    RequirementGroupsResource,
    AsyncRequirementGroupsResource,
    RequirementGroupsResourceWithRawResponse,
    AsyncRequirementGroupsResourceWithRawResponse,
    RequirementGroupsResourceWithStreamingResponse,
    AsyncRequirementGroupsResourceWithStreamingResponse,
)
from .texml_applications import (
    TexmlApplicationsResource,
    AsyncTexmlApplicationsResource,
    TexmlApplicationsResourceWithRawResponse,
    AsyncTexmlApplicationsResourceWithRawResponse,
    TexmlApplicationsResourceWithStreamingResponse,
    AsyncTexmlApplicationsResourceWithStreamingResponse,
)
from .webhook_deliveries import (
    WebhookDeliveriesResource,
    AsyncWebhookDeliveriesResource,
    WebhookDeliveriesResourceWithRawResponse,
    AsyncWebhookDeliveriesResourceWithRawResponse,
    WebhookDeliveriesResourceWithStreamingResponse,
    AsyncWebhookDeliveriesResourceWithStreamingResponse,
)
from .global_ip_protocols import (
    GlobalIPProtocolsResource,
    AsyncGlobalIPProtocolsResource,
    GlobalIPProtocolsResourceWithRawResponse,
    AsyncGlobalIPProtocolsResourceWithRawResponse,
    GlobalIPProtocolsResourceWithStreamingResponse,
    AsyncGlobalIPProtocolsResourceWithStreamingResponse,
)
from .integration_secrets import (
    IntegrationSecretsResource,
    AsyncIntegrationSecretsResource,
    IntegrationSecretsResourceWithRawResponse,
    AsyncIntegrationSecretsResourceWithRawResponse,
    IntegrationSecretsResourceWithStreamingResponse,
    AsyncIntegrationSecretsResourceWithStreamingResponse,
)
from .notification_events import (
    NotificationEventsResource,
    AsyncNotificationEventsResource,
    NotificationEventsResourceWithRawResponse,
    AsyncNotificationEventsResourceWithRawResponse,
    NotificationEventsResourceWithStreamingResponse,
    AsyncNotificationEventsResourceWithStreamingResponse,
)
from .number_block_orders import (
    NumberBlockOrdersResource,
    AsyncNumberBlockOrdersResource,
    NumberBlockOrdersResourceWithRawResponse,
    AsyncNumberBlockOrdersResourceWithRawResponse,
    NumberBlockOrdersResourceWithStreamingResponse,
    AsyncNumberBlockOrdersResourceWithStreamingResponse,
)
from .number_reservations import (
    NumberReservationsResource,
    AsyncNumberReservationsResource,
    NumberReservationsResourceWithRawResponse,
    AsyncNumberReservationsResourceWithRawResponse,
    NumberReservationsResourceWithStreamingResponse,
    AsyncNumberReservationsResourceWithStreamingResponse,
)
from .phone_number_blocks import (
    PhoneNumberBlocksResource,
    AsyncPhoneNumberBlocksResource,
    PhoneNumberBlocksResourceWithRawResponse,
    AsyncPhoneNumberBlocksResourceWithRawResponse,
    PhoneNumberBlocksResourceWithStreamingResponse,
    AsyncPhoneNumberBlocksResourceWithStreamingResponse,
)
from .wireless_blocklists import (
    WirelessBlocklistsResource,
    AsyncWirelessBlocklistsResource,
    WirelessBlocklistsResourceWithRawResponse,
    AsyncWirelessBlocklistsResourceWithRawResponse,
    WirelessBlocklistsResourceWithStreamingResponse,
    AsyncWirelessBlocklistsResourceWithStreamingResponse,
)
from .external_connections import (
    ExternalConnectionsResource,
    AsyncExternalConnectionsResource,
    ExternalConnectionsResourceWithRawResponse,
    AsyncExternalConnectionsResourceWithRawResponse,
    ExternalConnectionsResourceWithStreamingResponse,
    AsyncExternalConnectionsResourceWithStreamingResponse,
)
from .wireguard_interfaces import (
    WireguardInterfacesResource,
    AsyncWireguardInterfacesResource,
    WireguardInterfacesResourceWithRawResponse,
    AsyncWireguardInterfacesResourceWithRawResponse,
    WireguardInterfacesResourceWithStreamingResponse,
    AsyncWireguardInterfacesResourceWithStreamingResponse,
)
from .bulk_sim_card_actions import (
    BulkSimCardActionsResource,
    AsyncBulkSimCardActionsResource,
    BulkSimCardActionsResourceWithRawResponse,
    AsyncBulkSimCardActionsResourceWithRawResponse,
    BulkSimCardActionsResourceWithStreamingResponse,
    AsyncBulkSimCardActionsResourceWithStreamingResponse,
)
from .global_ip_assignments import (
    GlobalIPAssignmentsResource,
    AsyncGlobalIPAssignmentsResource,
    GlobalIPAssignmentsResourceWithRawResponse,
    AsyncGlobalIPAssignmentsResourceWithRawResponse,
    GlobalIPAssignmentsResourceWithStreamingResponse,
    AsyncGlobalIPAssignmentsResourceWithStreamingResponse,
)
from .messaging_url_domains import (
    MessagingURLDomainsResource,
    AsyncMessagingURLDomainsResource,
    MessagingURLDomainsResourceWithRawResponse,
    AsyncMessagingURLDomainsResourceWithRawResponse,
    MessagingURLDomainsResourceWithStreamingResponse,
    AsyncMessagingURLDomainsResourceWithStreamingResponse,
)
from .notification_channels import (
    NotificationChannelsResource,
    AsyncNotificationChannelsResource,
    NotificationChannelsResourceWithRawResponse,
    AsyncNotificationChannelsResourceWithRawResponse,
    NotificationChannelsResourceWithStreamingResponse,
    AsyncNotificationChannelsResourceWithStreamingResponse,
)
from .notification_profiles import (
    NotificationProfilesResource,
    AsyncNotificationProfilesResource,
    NotificationProfilesResourceWithRawResponse,
    AsyncNotificationProfilesResourceWithRawResponse,
    NotificationProfilesResourceWithStreamingResponse,
    AsyncNotificationProfilesResourceWithStreamingResponse,
)
from .notification_settings import (
    NotificationSettingsResource,
    AsyncNotificationSettingsResource,
    NotificationSettingsResourceWithRawResponse,
    AsyncNotificationSettingsResourceWithRawResponse,
    NotificationSettingsResourceWithStreamingResponse,
    AsyncNotificationSettingsResourceWithStreamingResponse,
)
from .porting_phone_numbers import (
    PortingPhoneNumbersResource,
    AsyncPortingPhoneNumbersResource,
    PortingPhoneNumbersResourceWithRawResponse,
    AsyncPortingPhoneNumbersResourceWithRawResponse,
    PortingPhoneNumbersResourceWithStreamingResponse,
    AsyncPortingPhoneNumbersResourceWithStreamingResponse,
)
from .telephony_credentials import (
    TelephonyCredentialsResource,
    AsyncTelephonyCredentialsResource,
    TelephonyCredentialsResourceWithRawResponse,
    AsyncTelephonyCredentialsResourceWithRawResponse,
    TelephonyCredentialsResourceWithStreamingResponse,
    AsyncTelephonyCredentialsResourceWithStreamingResponse,
)
from .credential_connections import (
    CredentialConnectionsResource,
    AsyncCredentialConnectionsResource,
    CredentialConnectionsResourceWithRawResponse,
    AsyncCredentialConnectionsResourceWithRawResponse,
    CredentialConnectionsResourceWithStreamingResponse,
    AsyncCredentialConnectionsResourceWithStreamingResponse,
)
from .dialogflow_connections import (
    DialogflowConnectionsResource,
    AsyncDialogflowConnectionsResource,
    DialogflowConnectionsResourceWithRawResponse,
    AsyncDialogflowConnectionsResourceWithRawResponse,
    DialogflowConnectionsResourceWithStreamingResponse,
    AsyncDialogflowConnectionsResourceWithStreamingResponse,
)
from .phone_number_campaigns import (
    PhoneNumberCampaignsResource,
    AsyncPhoneNumberCampaignsResource,
    PhoneNumberCampaignsResourceWithRawResponse,
    AsyncPhoneNumberCampaignsResourceWithRawResponse,
    PhoneNumberCampaignsResourceWithStreamingResponse,
    AsyncPhoneNumberCampaignsResourceWithStreamingResponse,
)
from .sim_card_order_preview import (
    SimCardOrderPreviewResource,
    AsyncSimCardOrderPreviewResource,
    SimCardOrderPreviewResourceWithRawResponse,
    AsyncSimCardOrderPreviewResourceWithRawResponse,
    SimCardOrderPreviewResourceWithStreamingResponse,
    AsyncSimCardOrderPreviewResourceWithStreamingResponse,
)
from .virtual_cross_connects import (
    VirtualCrossConnectsResource,
    AsyncVirtualCrossConnectsResource,
    VirtualCrossConnectsResourceWithRawResponse,
    AsyncVirtualCrossConnectsResourceWithRawResponse,
    VirtualCrossConnectsResourceWithStreamingResponse,
    AsyncVirtualCrossConnectsResourceWithStreamingResponse,
)
from .available_phone_numbers import (
    AvailablePhoneNumbersResource,
    AsyncAvailablePhoneNumbersResource,
    AvailablePhoneNumbersResourceWithRawResponse,
    AsyncAvailablePhoneNumbersResourceWithRawResponse,
    AvailablePhoneNumbersResourceWithStreamingResponse,
    AsyncAvailablePhoneNumbersResourceWithStreamingResponse,
)
from .global_ip_allowed_ports import (
    GlobalIPAllowedPortsResource,
    AsyncGlobalIPAllowedPortsResource,
    GlobalIPAllowedPortsResourceWithRawResponse,
    AsyncGlobalIPAllowedPortsResourceWithRawResponse,
    GlobalIPAllowedPortsResourceWithStreamingResponse,
    AsyncGlobalIPAllowedPortsResourceWithStreamingResponse,
)
from .global_ip_health_checks import (
    GlobalIPHealthChecksResource,
    AsyncGlobalIPHealthChecksResource,
    GlobalIPHealthChecksResourceWithRawResponse,
    AsyncGlobalIPHealthChecksResourceWithRawResponse,
    GlobalIPHealthChecksResourceWithStreamingResponse,
    AsyncGlobalIPHealthChecksResourceWithStreamingResponse,
)
from .mobile_push_credentials import (
    MobilePushCredentialsResource,
    AsyncMobilePushCredentialsResource,
    MobilePushCredentialsResourceWithRawResponse,
    AsyncMobilePushCredentialsResourceWithRawResponse,
    MobilePushCredentialsResourceWithStreamingResponse,
    AsyncMobilePushCredentialsResourceWithStreamingResponse,
)
from .outbound_voice_profiles import (
    OutboundVoiceProfilesResource,
    AsyncOutboundVoiceProfilesResource,
    OutboundVoiceProfilesResourceWithRawResponse,
    AsyncOutboundVoiceProfilesResourceWithRawResponse,
    OutboundVoiceProfilesResourceWithStreamingResponse,
    AsyncOutboundVoiceProfilesResourceWithStreamingResponse,
)
from .regulatory_requirements import (
    RegulatoryRequirementsResource,
    AsyncRegulatoryRequirementsResource,
    RegulatoryRequirementsResourceWithRawResponse,
    AsyncRegulatoryRequirementsResourceWithRawResponse,
    RegulatoryRequirementsResourceWithStreamingResponse,
    AsyncRegulatoryRequirementsResourceWithStreamingResponse,
)
from .authentication_providers import (
    AuthenticationProvidersResource,
    AsyncAuthenticationProvidersResource,
    AuthenticationProvidersResourceWithRawResponse,
    AsyncAuthenticationProvidersResourceWithRawResponse,
    AuthenticationProvidersResourceWithStreamingResponse,
    AsyncAuthenticationProvidersResourceWithStreamingResponse,
)
from .customer_service_records import (
    CustomerServiceRecordsResource,
    AsyncCustomerServiceRecordsResource,
    CustomerServiceRecordsResourceWithRawResponse,
    AsyncCustomerServiceRecordsResourceWithRawResponse,
    CustomerServiceRecordsResourceWithStreamingResponse,
    AsyncCustomerServiceRecordsResourceWithStreamingResponse,
)
from .messaging_hosted_numbers import (
    MessagingHostedNumbersResource,
    AsyncMessagingHostedNumbersResource,
    MessagingHostedNumbersResourceWithRawResponse,
    AsyncMessagingHostedNumbersResourceWithRawResponse,
    MessagingHostedNumbersResourceWithStreamingResponse,
    AsyncMessagingHostedNumbersResourceWithStreamingResponse,
)
from .mobile_network_operators import (
    MobileNetworkOperatorsResource,
    AsyncMobileNetworkOperatorsResource,
    MobileNetworkOperatorsResourceWithRawResponse,
    AsyncMobileNetworkOperatorsResourceWithRawResponse,
    MobileNetworkOperatorsResourceWithStreamingResponse,
    AsyncMobileNetworkOperatorsResourceWithStreamingResponse,
)
from .public_internet_gateways import (
    PublicInternetGatewaysResource,
    AsyncPublicInternetGatewaysResource,
    PublicInternetGatewaysResourceWithRawResponse,
    AsyncPublicInternetGatewaysResourceWithRawResponse,
    PublicInternetGatewaysResourceWithStreamingResponse,
    AsyncPublicInternetGatewaysResourceWithStreamingResponse,
)
from .recording_transcriptions import (
    RecordingTranscriptionsResource,
    AsyncRecordingTranscriptionsResource,
    RecordingTranscriptionsResourceWithRawResponse,
    AsyncRecordingTranscriptionsResourceWithRawResponse,
    RecordingTranscriptionsResourceWithStreamingResponse,
    AsyncRecordingTranscriptionsResourceWithStreamingResponse,
)
from .sub_number_orders_report import (
    SubNumberOrdersReportResource,
    AsyncSubNumberOrdersReportResource,
    SubNumberOrdersReportResourceWithRawResponse,
    AsyncSubNumberOrdersReportResourceWithRawResponse,
    SubNumberOrdersReportResourceWithStreamingResponse,
    AsyncSubNumberOrdersReportResourceWithStreamingResponse,
)
from .call_control_applications import (
    CallControlApplicationsResource,
    AsyncCallControlApplicationsResource,
    CallControlApplicationsResourceWithRawResponse,
    AsyncCallControlApplicationsResourceWithRawResponse,
    CallControlApplicationsResourceWithStreamingResponse,
    AsyncCallControlApplicationsResourceWithStreamingResponse,
)
from .private_wireless_gateways import (
    PrivateWirelessGatewaysResource,
    AsyncPrivateWirelessGatewaysResource,
    PrivateWirelessGatewaysResourceWithRawResponse,
    AsyncPrivateWirelessGatewaysResourceWithRawResponse,
    PrivateWirelessGatewaysResourceWithStreamingResponse,
    AsyncPrivateWirelessGatewaysResourceWithStreamingResponse,
)
from .wireless_blocklist_values import (
    WirelessBlocklistValuesResource,
    AsyncWirelessBlocklistValuesResource,
    WirelessBlocklistValuesResourceWithRawResponse,
    AsyncWirelessBlocklistValuesResourceWithRawResponse,
    WirelessBlocklistValuesResourceWithStreamingResponse,
    AsyncWirelessBlocklistValuesResourceWithStreamingResponse,
)
from .custom_storage_credentials import (
    CustomStorageCredentialsResource,
    AsyncCustomStorageCredentialsResource,
    CustomStorageCredentialsResourceWithRawResponse,
    AsyncCustomStorageCredentialsResourceWithRawResponse,
    CustomStorageCredentialsResourceWithStreamingResponse,
    AsyncCustomStorageCredentialsResourceWithStreamingResponse,
)
from .number_order_phone_numbers import (
    NumberOrderPhoneNumbersResource,
    AsyncNumberOrderPhoneNumbersResource,
    NumberOrderPhoneNumbersResourceWithRawResponse,
    AsyncNumberOrderPhoneNumbersResourceWithRawResponse,
    NumberOrderPhoneNumbersResourceWithStreamingResponse,
    AsyncNumberOrderPhoneNumbersResourceWithStreamingResponse,
)
from .dynamic_emergency_addresses import (
    DynamicEmergencyAddressesResource,
    AsyncDynamicEmergencyAddressesResource,
    DynamicEmergencyAddressesResourceWithRawResponse,
    AsyncDynamicEmergencyAddressesResourceWithRawResponse,
    DynamicEmergencyAddressesResourceWithStreamingResponse,
    AsyncDynamicEmergencyAddressesResourceWithStreamingResponse,
)
from .dynamic_emergency_endpoints import (
    DynamicEmergencyEndpointsResource,
    AsyncDynamicEmergencyEndpointsResource,
    DynamicEmergencyEndpointsResourceWithRawResponse,
    AsyncDynamicEmergencyEndpointsResourceWithRawResponse,
    DynamicEmergencyEndpointsResourceWithStreamingResponse,
    AsyncDynamicEmergencyEndpointsResourceWithStreamingResponse,
)
from .global_ip_assignment_health import (
    GlobalIPAssignmentHealthResource,
    AsyncGlobalIPAssignmentHealthResource,
    GlobalIPAssignmentHealthResourceWithRawResponse,
    AsyncGlobalIPAssignmentHealthResourceWithRawResponse,
    GlobalIPAssignmentHealthResourceWithStreamingResponse,
    AsyncGlobalIPAssignmentHealthResourceWithStreamingResponse,
)
from .global_ip_assignments_usage import (
    GlobalIPAssignmentsUsageResource,
    AsyncGlobalIPAssignmentsUsageResource,
    GlobalIPAssignmentsUsageResourceWithRawResponse,
    AsyncGlobalIPAssignmentsUsageResourceWithRawResponse,
    GlobalIPAssignmentsUsageResourceWithStreamingResponse,
    AsyncGlobalIPAssignmentsUsageResourceWithStreamingResponse,
)
from .global_ip_health_check_types import (
    GlobalIPHealthCheckTypesResource,
    AsyncGlobalIPHealthCheckTypesResource,
    GlobalIPHealthCheckTypesResourceWithRawResponse,
    AsyncGlobalIPHealthCheckTypesResourceWithRawResponse,
    GlobalIPHealthCheckTypesResourceWithStreamingResponse,
    AsyncGlobalIPHealthCheckTypesResourceWithStreamingResponse,
)
from .ledger_billing_group_reports import (
    LedgerBillingGroupReportsResource,
    AsyncLedgerBillingGroupReportsResource,
    LedgerBillingGroupReportsResourceWithRawResponse,
    AsyncLedgerBillingGroupReportsResourceWithRawResponse,
    LedgerBillingGroupReportsResourceWithStreamingResponse,
    AsyncLedgerBillingGroupReportsResourceWithStreamingResponse,
)
from .available_phone_number_blocks import (
    AvailablePhoneNumberBlocksResource,
    AsyncAvailablePhoneNumberBlocksResource,
    AvailablePhoneNumberBlocksResourceWithRawResponse,
    AsyncAvailablePhoneNumberBlocksResourceWithRawResponse,
    AvailablePhoneNumberBlocksResourceWithStreamingResponse,
    AsyncAvailablePhoneNumberBlocksResourceWithStreamingResponse,
)
from .notification_event_conditions import (
    NotificationEventConditionsResource,
    AsyncNotificationEventConditionsResource,
    NotificationEventConditionsResourceWithRawResponse,
    AsyncNotificationEventConditionsResourceWithRawResponse,
    NotificationEventConditionsResourceWithStreamingResponse,
    AsyncNotificationEventConditionsResourceWithStreamingResponse,
)
from .messaging_hosted_number_orders import (
    MessagingHostedNumberOrdersResource,
    AsyncMessagingHostedNumberOrdersResource,
    MessagingHostedNumberOrdersResourceWithRawResponse,
    AsyncMessagingHostedNumberOrdersResourceWithRawResponse,
    MessagingHostedNumberOrdersResourceWithStreamingResponse,
    AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse,
)
from .messaging_numbers_bulk_updates import (
    MessagingNumbersBulkUpdatesResource,
    AsyncMessagingNumbersBulkUpdatesResource,
    MessagingNumbersBulkUpdatesResourceWithRawResponse,
    AsyncMessagingNumbersBulkUpdatesResourceWithRawResponse,
    MessagingNumbersBulkUpdatesResourceWithStreamingResponse,
    AsyncMessagingNumbersBulkUpdatesResourceWithStreamingResponse,
)
from .virtual_cross_connects_coverage import (
    VirtualCrossConnectsCoverageResource,
    AsyncVirtualCrossConnectsCoverageResource,
    VirtualCrossConnectsCoverageResourceWithRawResponse,
    AsyncVirtualCrossConnectsCoverageResourceWithRawResponse,
    VirtualCrossConnectsCoverageResourceWithStreamingResponse,
    AsyncVirtualCrossConnectsCoverageResourceWithStreamingResponse,
)
from .sim_card_data_usage_notifications import (
    SimCardDataUsageNotificationsResource,
    AsyncSimCardDataUsageNotificationsResource,
    SimCardDataUsageNotificationsResourceWithRawResponse,
    AsyncSimCardDataUsageNotificationsResourceWithRawResponse,
    SimCardDataUsageNotificationsResourceWithStreamingResponse,
    AsyncSimCardDataUsageNotificationsResourceWithStreamingResponse,
)
from .phone_number_assignment_by_profile import (
    PhoneNumberAssignmentByProfileResource,
    AsyncPhoneNumberAssignmentByProfileResource,
    PhoneNumberAssignmentByProfileResourceWithRawResponse,
    AsyncPhoneNumberAssignmentByProfileResourceWithRawResponse,
    PhoneNumberAssignmentByProfileResourceWithStreamingResponse,
    AsyncPhoneNumberAssignmentByProfileResourceWithStreamingResponse,
)
from .phone_numbers_regulatory_requirements import (
    PhoneNumbersRegulatoryRequirementsResource,
    AsyncPhoneNumbersRegulatoryRequirementsResource,
    PhoneNumbersRegulatoryRequirementsResourceWithRawResponse,
    AsyncPhoneNumbersRegulatoryRequirementsResourceWithRawResponse,
    PhoneNumbersRegulatoryRequirementsResourceWithStreamingResponse,
    AsyncPhoneNumbersRegulatoryRequirementsResourceWithStreamingResponse,
)

__all__ = [
    "LegacyResource",
    "AsyncLegacyResource",
    "LegacyResourceWithRawResponse",
    "AsyncLegacyResourceWithRawResponse",
    "LegacyResourceWithStreamingResponse",
    "AsyncLegacyResourceWithStreamingResponse",
    "OAuthResource",
    "AsyncOAuthResource",
    "OAuthResourceWithRawResponse",
    "AsyncOAuthResourceWithRawResponse",
    "OAuthResourceWithStreamingResponse",
    "AsyncOAuthResourceWithStreamingResponse",
    "OAuthClientsResource",
    "AsyncOAuthClientsResource",
    "OAuthClientsResourceWithRawResponse",
    "AsyncOAuthClientsResourceWithRawResponse",
    "OAuthClientsResourceWithStreamingResponse",
    "AsyncOAuthClientsResourceWithStreamingResponse",
    "OAuthGrantsResource",
    "AsyncOAuthGrantsResource",
    "OAuthGrantsResourceWithRawResponse",
    "AsyncOAuthGrantsResourceWithRawResponse",
    "OAuthGrantsResourceWithStreamingResponse",
    "AsyncOAuthGrantsResourceWithStreamingResponse",
    "WebhooksResource",
    "AsyncWebhooksResource",
    "TelnyxWebhook",
    "TelnyxWebhookVerificationError",
    "AccessIPAddressResource",
    "AsyncAccessIPAddressResource",
    "AccessIPAddressResourceWithRawResponse",
    "AsyncAccessIPAddressResourceWithRawResponse",
    "AccessIPAddressResourceWithStreamingResponse",
    "AsyncAccessIPAddressResourceWithStreamingResponse",
    "AccessIPRangesResource",
    "AsyncAccessIPRangesResource",
    "AccessIPRangesResourceWithRawResponse",
    "AsyncAccessIPRangesResourceWithRawResponse",
    "AccessIPRangesResourceWithStreamingResponse",
    "AsyncAccessIPRangesResourceWithStreamingResponse",
    "ActionsResource",
    "AsyncActionsResource",
    "ActionsResourceWithRawResponse",
    "AsyncActionsResourceWithRawResponse",
    "ActionsResourceWithStreamingResponse",
    "AsyncActionsResourceWithStreamingResponse",
    "AddressesResource",
    "AsyncAddressesResource",
    "AddressesResourceWithRawResponse",
    "AsyncAddressesResourceWithRawResponse",
    "AddressesResourceWithStreamingResponse",
    "AsyncAddressesResourceWithStreamingResponse",
    "AdvancedOrdersResource",
    "AsyncAdvancedOrdersResource",
    "AdvancedOrdersResourceWithRawResponse",
    "AsyncAdvancedOrdersResourceWithRawResponse",
    "AdvancedOrdersResourceWithStreamingResponse",
    "AsyncAdvancedOrdersResourceWithStreamingResponse",
    "AIResource",
    "AsyncAIResource",
    "AIResourceWithRawResponse",
    "AsyncAIResourceWithRawResponse",
    "AIResourceWithStreamingResponse",
    "AsyncAIResourceWithStreamingResponse",
    "AuditEventsResource",
    "AsyncAuditEventsResource",
    "AuditEventsResourceWithRawResponse",
    "AsyncAuditEventsResourceWithRawResponse",
    "AuditEventsResourceWithStreamingResponse",
    "AsyncAuditEventsResourceWithStreamingResponse",
    "AuthenticationProvidersResource",
    "AsyncAuthenticationProvidersResource",
    "AuthenticationProvidersResourceWithRawResponse",
    "AsyncAuthenticationProvidersResourceWithRawResponse",
    "AuthenticationProvidersResourceWithStreamingResponse",
    "AsyncAuthenticationProvidersResourceWithStreamingResponse",
    "AvailablePhoneNumberBlocksResource",
    "AsyncAvailablePhoneNumberBlocksResource",
    "AvailablePhoneNumberBlocksResourceWithRawResponse",
    "AsyncAvailablePhoneNumberBlocksResourceWithRawResponse",
    "AvailablePhoneNumberBlocksResourceWithStreamingResponse",
    "AsyncAvailablePhoneNumberBlocksResourceWithStreamingResponse",
    "AvailablePhoneNumbersResource",
    "AsyncAvailablePhoneNumbersResource",
    "AvailablePhoneNumbersResourceWithRawResponse",
    "AsyncAvailablePhoneNumbersResourceWithRawResponse",
    "AvailablePhoneNumbersResourceWithStreamingResponse",
    "AsyncAvailablePhoneNumbersResourceWithStreamingResponse",
    "BalanceResource",
    "AsyncBalanceResource",
    "BalanceResourceWithRawResponse",
    "AsyncBalanceResourceWithRawResponse",
    "BalanceResourceWithStreamingResponse",
    "AsyncBalanceResourceWithStreamingResponse",
    "BillingGroupsResource",
    "AsyncBillingGroupsResource",
    "BillingGroupsResourceWithRawResponse",
    "AsyncBillingGroupsResourceWithRawResponse",
    "BillingGroupsResourceWithStreamingResponse",
    "AsyncBillingGroupsResourceWithStreamingResponse",
    "BrandResource",
    "AsyncBrandResource",
    "BrandResourceWithRawResponse",
    "AsyncBrandResourceWithRawResponse",
    "BrandResourceWithStreamingResponse",
    "AsyncBrandResourceWithStreamingResponse",
    "BulkSimCardActionsResource",
    "AsyncBulkSimCardActionsResource",
    "BulkSimCardActionsResourceWithRawResponse",
    "AsyncBulkSimCardActionsResourceWithRawResponse",
    "BulkSimCardActionsResourceWithStreamingResponse",
    "AsyncBulkSimCardActionsResourceWithStreamingResponse",
    "BundlePricingResource",
    "AsyncBundlePricingResource",
    "BundlePricingResourceWithRawResponse",
    "AsyncBundlePricingResourceWithRawResponse",
    "BundlePricingResourceWithStreamingResponse",
    "AsyncBundlePricingResourceWithStreamingResponse",
    "CallControlApplicationsResource",
    "AsyncCallControlApplicationsResource",
    "CallControlApplicationsResourceWithRawResponse",
    "AsyncCallControlApplicationsResourceWithRawResponse",
    "CallControlApplicationsResourceWithStreamingResponse",
    "AsyncCallControlApplicationsResourceWithStreamingResponse",
    "CallEventsResource",
    "AsyncCallEventsResource",
    "CallEventsResourceWithRawResponse",
    "AsyncCallEventsResourceWithRawResponse",
    "CallEventsResourceWithStreamingResponse",
    "AsyncCallEventsResourceWithStreamingResponse",
    "CallsResource",
    "AsyncCallsResource",
    "CallsResourceWithRawResponse",
    "AsyncCallsResourceWithRawResponse",
    "CallsResourceWithStreamingResponse",
    "AsyncCallsResourceWithStreamingResponse",
    "CampaignResource",
    "AsyncCampaignResource",
    "CampaignResourceWithRawResponse",
    "AsyncCampaignResourceWithRawResponse",
    "CampaignResourceWithStreamingResponse",
    "AsyncCampaignResourceWithStreamingResponse",
    "CampaignBuilderResource",
    "AsyncCampaignBuilderResource",
    "CampaignBuilderResourceWithRawResponse",
    "AsyncCampaignBuilderResourceWithRawResponse",
    "CampaignBuilderResourceWithStreamingResponse",
    "AsyncCampaignBuilderResourceWithStreamingResponse",
    "ChannelZonesResource",
    "AsyncChannelZonesResource",
    "ChannelZonesResourceWithRawResponse",
    "AsyncChannelZonesResourceWithRawResponse",
    "ChannelZonesResourceWithStreamingResponse",
    "AsyncChannelZonesResourceWithStreamingResponse",
    "ChargesBreakdownResource",
    "AsyncChargesBreakdownResource",
    "ChargesBreakdownResourceWithRawResponse",
    "AsyncChargesBreakdownResourceWithRawResponse",
    "ChargesBreakdownResourceWithStreamingResponse",
    "AsyncChargesBreakdownResourceWithStreamingResponse",
    "ChargesSummaryResource",
    "AsyncChargesSummaryResource",
    "ChargesSummaryResourceWithRawResponse",
    "AsyncChargesSummaryResourceWithRawResponse",
    "ChargesSummaryResourceWithStreamingResponse",
    "AsyncChargesSummaryResourceWithStreamingResponse",
    "CommentsResource",
    "AsyncCommentsResource",
    "CommentsResourceWithRawResponse",
    "AsyncCommentsResourceWithRawResponse",
    "CommentsResourceWithStreamingResponse",
    "AsyncCommentsResourceWithStreamingResponse",
    "ConferencesResource",
    "AsyncConferencesResource",
    "ConferencesResourceWithRawResponse",
    "AsyncConferencesResourceWithRawResponse",
    "ConferencesResourceWithStreamingResponse",
    "AsyncConferencesResourceWithStreamingResponse",
    "ConnectionsResource",
    "AsyncConnectionsResource",
    "ConnectionsResourceWithRawResponse",
    "AsyncConnectionsResourceWithRawResponse",
    "ConnectionsResourceWithStreamingResponse",
    "AsyncConnectionsResourceWithStreamingResponse",
    "CountryCoverageResource",
    "AsyncCountryCoverageResource",
    "CountryCoverageResourceWithRawResponse",
    "AsyncCountryCoverageResourceWithRawResponse",
    "CountryCoverageResourceWithStreamingResponse",
    "AsyncCountryCoverageResourceWithStreamingResponse",
    "CredentialConnectionsResource",
    "AsyncCredentialConnectionsResource",
    "CredentialConnectionsResourceWithRawResponse",
    "AsyncCredentialConnectionsResourceWithRawResponse",
    "CredentialConnectionsResourceWithStreamingResponse",
    "AsyncCredentialConnectionsResourceWithStreamingResponse",
    "CustomStorageCredentialsResource",
    "AsyncCustomStorageCredentialsResource",
    "CustomStorageCredentialsResourceWithRawResponse",
    "AsyncCustomStorageCredentialsResourceWithRawResponse",
    "CustomStorageCredentialsResourceWithStreamingResponse",
    "AsyncCustomStorageCredentialsResourceWithStreamingResponse",
    "CustomerServiceRecordsResource",
    "AsyncCustomerServiceRecordsResource",
    "CustomerServiceRecordsResourceWithRawResponse",
    "AsyncCustomerServiceRecordsResourceWithRawResponse",
    "CustomerServiceRecordsResourceWithStreamingResponse",
    "AsyncCustomerServiceRecordsResourceWithStreamingResponse",
    "DetailRecordsResource",
    "AsyncDetailRecordsResource",
    "DetailRecordsResourceWithRawResponse",
    "AsyncDetailRecordsResourceWithRawResponse",
    "DetailRecordsResourceWithStreamingResponse",
    "AsyncDetailRecordsResourceWithStreamingResponse",
    "DialogflowConnectionsResource",
    "AsyncDialogflowConnectionsResource",
    "DialogflowConnectionsResourceWithRawResponse",
    "AsyncDialogflowConnectionsResourceWithRawResponse",
    "DialogflowConnectionsResourceWithStreamingResponse",
    "AsyncDialogflowConnectionsResourceWithStreamingResponse",
    "DocumentLinksResource",
    "AsyncDocumentLinksResource",
    "DocumentLinksResourceWithRawResponse",
    "AsyncDocumentLinksResourceWithRawResponse",
    "DocumentLinksResourceWithStreamingResponse",
    "AsyncDocumentLinksResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
    "DynamicEmergencyAddressesResource",
    "AsyncDynamicEmergencyAddressesResource",
    "DynamicEmergencyAddressesResourceWithRawResponse",
    "AsyncDynamicEmergencyAddressesResourceWithRawResponse",
    "DynamicEmergencyAddressesResourceWithStreamingResponse",
    "AsyncDynamicEmergencyAddressesResourceWithStreamingResponse",
    "DynamicEmergencyEndpointsResource",
    "AsyncDynamicEmergencyEndpointsResource",
    "DynamicEmergencyEndpointsResourceWithRawResponse",
    "AsyncDynamicEmergencyEndpointsResourceWithRawResponse",
    "DynamicEmergencyEndpointsResourceWithStreamingResponse",
    "AsyncDynamicEmergencyEndpointsResourceWithStreamingResponse",
    "EnumResource",
    "AsyncEnumResource",
    "EnumResourceWithRawResponse",
    "AsyncEnumResourceWithRawResponse",
    "EnumResourceWithStreamingResponse",
    "AsyncEnumResourceWithStreamingResponse",
    "ExternalConnectionsResource",
    "AsyncExternalConnectionsResource",
    "ExternalConnectionsResourceWithRawResponse",
    "AsyncExternalConnectionsResourceWithRawResponse",
    "ExternalConnectionsResourceWithStreamingResponse",
    "AsyncExternalConnectionsResourceWithStreamingResponse",
    "FaxApplicationsResource",
    "AsyncFaxApplicationsResource",
    "FaxApplicationsResourceWithRawResponse",
    "AsyncFaxApplicationsResourceWithRawResponse",
    "FaxApplicationsResourceWithStreamingResponse",
    "AsyncFaxApplicationsResourceWithStreamingResponse",
    "FaxesResource",
    "AsyncFaxesResource",
    "FaxesResourceWithRawResponse",
    "AsyncFaxesResourceWithRawResponse",
    "FaxesResourceWithStreamingResponse",
    "AsyncFaxesResourceWithStreamingResponse",
    "FqdnConnectionsResource",
    "AsyncFqdnConnectionsResource",
    "FqdnConnectionsResourceWithRawResponse",
    "AsyncFqdnConnectionsResourceWithRawResponse",
    "FqdnConnectionsResourceWithStreamingResponse",
    "AsyncFqdnConnectionsResourceWithStreamingResponse",
    "FqdnsResource",
    "AsyncFqdnsResource",
    "FqdnsResourceWithRawResponse",
    "AsyncFqdnsResourceWithRawResponse",
    "FqdnsResourceWithStreamingResponse",
    "AsyncFqdnsResourceWithStreamingResponse",
    "GlobalIPAllowedPortsResource",
    "AsyncGlobalIPAllowedPortsResource",
    "GlobalIPAllowedPortsResourceWithRawResponse",
    "AsyncGlobalIPAllowedPortsResourceWithRawResponse",
    "GlobalIPAllowedPortsResourceWithStreamingResponse",
    "AsyncGlobalIPAllowedPortsResourceWithStreamingResponse",
    "GlobalIPAssignmentHealthResource",
    "AsyncGlobalIPAssignmentHealthResource",
    "GlobalIPAssignmentHealthResourceWithRawResponse",
    "AsyncGlobalIPAssignmentHealthResourceWithRawResponse",
    "GlobalIPAssignmentHealthResourceWithStreamingResponse",
    "AsyncGlobalIPAssignmentHealthResourceWithStreamingResponse",
    "GlobalIPAssignmentsResource",
    "AsyncGlobalIPAssignmentsResource",
    "GlobalIPAssignmentsResourceWithRawResponse",
    "AsyncGlobalIPAssignmentsResourceWithRawResponse",
    "GlobalIPAssignmentsResourceWithStreamingResponse",
    "AsyncGlobalIPAssignmentsResourceWithStreamingResponse",
    "GlobalIPAssignmentsUsageResource",
    "AsyncGlobalIPAssignmentsUsageResource",
    "GlobalIPAssignmentsUsageResourceWithRawResponse",
    "AsyncGlobalIPAssignmentsUsageResourceWithRawResponse",
    "GlobalIPAssignmentsUsageResourceWithStreamingResponse",
    "AsyncGlobalIPAssignmentsUsageResourceWithStreamingResponse",
    "GlobalIPHealthCheckTypesResource",
    "AsyncGlobalIPHealthCheckTypesResource",
    "GlobalIPHealthCheckTypesResourceWithRawResponse",
    "AsyncGlobalIPHealthCheckTypesResourceWithRawResponse",
    "GlobalIPHealthCheckTypesResourceWithStreamingResponse",
    "AsyncGlobalIPHealthCheckTypesResourceWithStreamingResponse",
    "GlobalIPHealthChecksResource",
    "AsyncGlobalIPHealthChecksResource",
    "GlobalIPHealthChecksResourceWithRawResponse",
    "AsyncGlobalIPHealthChecksResourceWithRawResponse",
    "GlobalIPHealthChecksResourceWithStreamingResponse",
    "AsyncGlobalIPHealthChecksResourceWithStreamingResponse",
    "GlobalIPLatencyResource",
    "AsyncGlobalIPLatencyResource",
    "GlobalIPLatencyResourceWithRawResponse",
    "AsyncGlobalIPLatencyResourceWithRawResponse",
    "GlobalIPLatencyResourceWithStreamingResponse",
    "AsyncGlobalIPLatencyResourceWithStreamingResponse",
    "GlobalIPProtocolsResource",
    "AsyncGlobalIPProtocolsResource",
    "GlobalIPProtocolsResourceWithRawResponse",
    "AsyncGlobalIPProtocolsResourceWithRawResponse",
    "GlobalIPProtocolsResourceWithStreamingResponse",
    "AsyncGlobalIPProtocolsResourceWithStreamingResponse",
    "GlobalIPUsageResource",
    "AsyncGlobalIPUsageResource",
    "GlobalIPUsageResourceWithRawResponse",
    "AsyncGlobalIPUsageResourceWithRawResponse",
    "GlobalIPUsageResourceWithStreamingResponse",
    "AsyncGlobalIPUsageResourceWithStreamingResponse",
    "GlobalIPsResource",
    "AsyncGlobalIPsResource",
    "GlobalIPsResourceWithRawResponse",
    "AsyncGlobalIPsResourceWithRawResponse",
    "GlobalIPsResourceWithStreamingResponse",
    "AsyncGlobalIPsResourceWithStreamingResponse",
    "InboundChannelsResource",
    "AsyncInboundChannelsResource",
    "InboundChannelsResourceWithRawResponse",
    "AsyncInboundChannelsResourceWithRawResponse",
    "InboundChannelsResourceWithStreamingResponse",
    "AsyncInboundChannelsResourceWithStreamingResponse",
    "IntegrationSecretsResource",
    "AsyncIntegrationSecretsResource",
    "IntegrationSecretsResourceWithRawResponse",
    "AsyncIntegrationSecretsResourceWithRawResponse",
    "IntegrationSecretsResourceWithStreamingResponse",
    "AsyncIntegrationSecretsResourceWithStreamingResponse",
    "InventoryCoverageResource",
    "AsyncInventoryCoverageResource",
    "InventoryCoverageResourceWithRawResponse",
    "AsyncInventoryCoverageResourceWithRawResponse",
    "InventoryCoverageResourceWithStreamingResponse",
    "AsyncInventoryCoverageResourceWithStreamingResponse",
    "InvoicesResource",
    "AsyncInvoicesResource",
    "InvoicesResourceWithRawResponse",
    "AsyncInvoicesResourceWithRawResponse",
    "InvoicesResourceWithStreamingResponse",
    "AsyncInvoicesResourceWithStreamingResponse",
    "IPConnectionsResource",
    "AsyncIPConnectionsResource",
    "IPConnectionsResourceWithRawResponse",
    "AsyncIPConnectionsResourceWithRawResponse",
    "IPConnectionsResourceWithStreamingResponse",
    "AsyncIPConnectionsResourceWithStreamingResponse",
    "IPsResource",
    "AsyncIPsResource",
    "IPsResourceWithRawResponse",
    "AsyncIPsResourceWithRawResponse",
    "IPsResourceWithStreamingResponse",
    "AsyncIPsResourceWithStreamingResponse",
    "LedgerBillingGroupReportsResource",
    "AsyncLedgerBillingGroupReportsResource",
    "LedgerBillingGroupReportsResourceWithRawResponse",
    "AsyncLedgerBillingGroupReportsResourceWithRawResponse",
    "LedgerBillingGroupReportsResourceWithStreamingResponse",
    "AsyncLedgerBillingGroupReportsResourceWithStreamingResponse",
    "ListResource",
    "AsyncListResource",
    "ListResourceWithRawResponse",
    "AsyncListResourceWithRawResponse",
    "ListResourceWithStreamingResponse",
    "AsyncListResourceWithStreamingResponse",
    "ManagedAccountsResource",
    "AsyncManagedAccountsResource",
    "ManagedAccountsResourceWithRawResponse",
    "AsyncManagedAccountsResourceWithRawResponse",
    "ManagedAccountsResourceWithStreamingResponse",
    "AsyncManagedAccountsResourceWithStreamingResponse",
    "MediaResource",
    "AsyncMediaResource",
    "MediaResourceWithRawResponse",
    "AsyncMediaResourceWithRawResponse",
    "MediaResourceWithStreamingResponse",
    "AsyncMediaResourceWithStreamingResponse",
    "MessagesResource",
    "AsyncMessagesResource",
    "MessagesResourceWithRawResponse",
    "AsyncMessagesResourceWithRawResponse",
    "MessagesResourceWithStreamingResponse",
    "AsyncMessagesResourceWithStreamingResponse",
    "MessagingResource",
    "AsyncMessagingResource",
    "MessagingResourceWithRawResponse",
    "AsyncMessagingResourceWithRawResponse",
    "MessagingResourceWithStreamingResponse",
    "AsyncMessagingResourceWithStreamingResponse",
    "MessagingHostedNumberOrdersResource",
    "AsyncMessagingHostedNumberOrdersResource",
    "MessagingHostedNumberOrdersResourceWithRawResponse",
    "AsyncMessagingHostedNumberOrdersResourceWithRawResponse",
    "MessagingHostedNumberOrdersResourceWithStreamingResponse",
    "AsyncMessagingHostedNumberOrdersResourceWithStreamingResponse",
    "MessagingHostedNumbersResource",
    "AsyncMessagingHostedNumbersResource",
    "MessagingHostedNumbersResourceWithRawResponse",
    "AsyncMessagingHostedNumbersResourceWithRawResponse",
    "MessagingHostedNumbersResourceWithStreamingResponse",
    "AsyncMessagingHostedNumbersResourceWithStreamingResponse",
    "MessagingNumbersBulkUpdatesResource",
    "AsyncMessagingNumbersBulkUpdatesResource",
    "MessagingNumbersBulkUpdatesResourceWithRawResponse",
    "AsyncMessagingNumbersBulkUpdatesResourceWithRawResponse",
    "MessagingNumbersBulkUpdatesResourceWithStreamingResponse",
    "AsyncMessagingNumbersBulkUpdatesResourceWithStreamingResponse",
    "MessagingOptoutsResource",
    "AsyncMessagingOptoutsResource",
    "MessagingOptoutsResourceWithRawResponse",
    "AsyncMessagingOptoutsResourceWithRawResponse",
    "MessagingOptoutsResourceWithStreamingResponse",
    "AsyncMessagingOptoutsResourceWithStreamingResponse",
    "MessagingProfilesResource",
    "AsyncMessagingProfilesResource",
    "MessagingProfilesResourceWithRawResponse",
    "AsyncMessagingProfilesResourceWithRawResponse",
    "MessagingProfilesResourceWithStreamingResponse",
    "AsyncMessagingProfilesResourceWithStreamingResponse",
    "MessagingTollfreeResource",
    "AsyncMessagingTollfreeResource",
    "MessagingTollfreeResourceWithRawResponse",
    "AsyncMessagingTollfreeResourceWithRawResponse",
    "MessagingTollfreeResourceWithStreamingResponse",
    "AsyncMessagingTollfreeResourceWithStreamingResponse",
    "MessagingURLDomainsResource",
    "AsyncMessagingURLDomainsResource",
    "MessagingURLDomainsResourceWithRawResponse",
    "AsyncMessagingURLDomainsResourceWithRawResponse",
    "MessagingURLDomainsResourceWithStreamingResponse",
    "AsyncMessagingURLDomainsResourceWithStreamingResponse",
    "MesssagesResource",
    "AsyncMesssagesResource",
    "MesssagesResourceWithRawResponse",
    "AsyncMesssagesResourceWithRawResponse",
    "MesssagesResourceWithStreamingResponse",
    "AsyncMesssagesResourceWithStreamingResponse",
    "MobileNetworkOperatorsResource",
    "AsyncMobileNetworkOperatorsResource",
    "MobileNetworkOperatorsResourceWithRawResponse",
    "AsyncMobileNetworkOperatorsResourceWithRawResponse",
    "MobileNetworkOperatorsResourceWithStreamingResponse",
    "AsyncMobileNetworkOperatorsResourceWithStreamingResponse",
    "MobilePushCredentialsResource",
    "AsyncMobilePushCredentialsResource",
    "MobilePushCredentialsResourceWithRawResponse",
    "AsyncMobilePushCredentialsResourceWithRawResponse",
    "MobilePushCredentialsResourceWithStreamingResponse",
    "AsyncMobilePushCredentialsResourceWithStreamingResponse",
    "NetworkCoverageResource",
    "AsyncNetworkCoverageResource",
    "NetworkCoverageResourceWithRawResponse",
    "AsyncNetworkCoverageResourceWithRawResponse",
    "NetworkCoverageResourceWithStreamingResponse",
    "AsyncNetworkCoverageResourceWithStreamingResponse",
    "NetworksResource",
    "AsyncNetworksResource",
    "NetworksResourceWithRawResponse",
    "AsyncNetworksResourceWithRawResponse",
    "NetworksResourceWithStreamingResponse",
    "AsyncNetworksResourceWithStreamingResponse",
    "NotificationChannelsResource",
    "AsyncNotificationChannelsResource",
    "NotificationChannelsResourceWithRawResponse",
    "AsyncNotificationChannelsResourceWithRawResponse",
    "NotificationChannelsResourceWithStreamingResponse",
    "AsyncNotificationChannelsResourceWithStreamingResponse",
    "NotificationEventConditionsResource",
    "AsyncNotificationEventConditionsResource",
    "NotificationEventConditionsResourceWithRawResponse",
    "AsyncNotificationEventConditionsResourceWithRawResponse",
    "NotificationEventConditionsResourceWithStreamingResponse",
    "AsyncNotificationEventConditionsResourceWithStreamingResponse",
    "NotificationEventsResource",
    "AsyncNotificationEventsResource",
    "NotificationEventsResourceWithRawResponse",
    "AsyncNotificationEventsResourceWithRawResponse",
    "NotificationEventsResourceWithStreamingResponse",
    "AsyncNotificationEventsResourceWithStreamingResponse",
    "NotificationProfilesResource",
    "AsyncNotificationProfilesResource",
    "NotificationProfilesResourceWithRawResponse",
    "AsyncNotificationProfilesResourceWithRawResponse",
    "NotificationProfilesResourceWithStreamingResponse",
    "AsyncNotificationProfilesResourceWithStreamingResponse",
    "NotificationSettingsResource",
    "AsyncNotificationSettingsResource",
    "NotificationSettingsResourceWithRawResponse",
    "AsyncNotificationSettingsResourceWithRawResponse",
    "NotificationSettingsResourceWithStreamingResponse",
    "AsyncNotificationSettingsResourceWithStreamingResponse",
    "NumberBlockOrdersResource",
    "AsyncNumberBlockOrdersResource",
    "NumberBlockOrdersResourceWithRawResponse",
    "AsyncNumberBlockOrdersResourceWithRawResponse",
    "NumberBlockOrdersResourceWithStreamingResponse",
    "AsyncNumberBlockOrdersResourceWithStreamingResponse",
    "NumberLookupResource",
    "AsyncNumberLookupResource",
    "NumberLookupResourceWithRawResponse",
    "AsyncNumberLookupResourceWithRawResponse",
    "NumberLookupResourceWithStreamingResponse",
    "AsyncNumberLookupResourceWithStreamingResponse",
    "NumberOrderPhoneNumbersResource",
    "AsyncNumberOrderPhoneNumbersResource",
    "NumberOrderPhoneNumbersResourceWithRawResponse",
    "AsyncNumberOrderPhoneNumbersResourceWithRawResponse",
    "NumberOrderPhoneNumbersResourceWithStreamingResponse",
    "AsyncNumberOrderPhoneNumbersResourceWithStreamingResponse",
    "NumberOrdersResource",
    "AsyncNumberOrdersResource",
    "NumberOrdersResourceWithRawResponse",
    "AsyncNumberOrdersResourceWithRawResponse",
    "NumberOrdersResourceWithStreamingResponse",
    "AsyncNumberOrdersResourceWithStreamingResponse",
    "NumberReservationsResource",
    "AsyncNumberReservationsResource",
    "NumberReservationsResourceWithRawResponse",
    "AsyncNumberReservationsResourceWithRawResponse",
    "NumberReservationsResourceWithStreamingResponse",
    "AsyncNumberReservationsResourceWithStreamingResponse",
    "NumbersFeaturesResource",
    "AsyncNumbersFeaturesResource",
    "NumbersFeaturesResourceWithRawResponse",
    "AsyncNumbersFeaturesResourceWithRawResponse",
    "NumbersFeaturesResourceWithStreamingResponse",
    "AsyncNumbersFeaturesResourceWithStreamingResponse",
    "OperatorConnectResource",
    "AsyncOperatorConnectResource",
    "OperatorConnectResourceWithRawResponse",
    "AsyncOperatorConnectResourceWithRawResponse",
    "OperatorConnectResourceWithStreamingResponse",
    "AsyncOperatorConnectResourceWithStreamingResponse",
    "OtaUpdatesResource",
    "AsyncOtaUpdatesResource",
    "OtaUpdatesResourceWithRawResponse",
    "AsyncOtaUpdatesResourceWithRawResponse",
    "OtaUpdatesResourceWithStreamingResponse",
    "AsyncOtaUpdatesResourceWithStreamingResponse",
    "OutboundVoiceProfilesResource",
    "AsyncOutboundVoiceProfilesResource",
    "OutboundVoiceProfilesResourceWithRawResponse",
    "AsyncOutboundVoiceProfilesResourceWithRawResponse",
    "OutboundVoiceProfilesResourceWithStreamingResponse",
    "AsyncOutboundVoiceProfilesResourceWithStreamingResponse",
    "PaymentResource",
    "AsyncPaymentResource",
    "PaymentResourceWithRawResponse",
    "AsyncPaymentResourceWithRawResponse",
    "PaymentResourceWithStreamingResponse",
    "AsyncPaymentResourceWithStreamingResponse",
    "PhoneNumberAssignmentByProfileResource",
    "AsyncPhoneNumberAssignmentByProfileResource",
    "PhoneNumberAssignmentByProfileResourceWithRawResponse",
    "AsyncPhoneNumberAssignmentByProfileResourceWithRawResponse",
    "PhoneNumberAssignmentByProfileResourceWithStreamingResponse",
    "AsyncPhoneNumberAssignmentByProfileResourceWithStreamingResponse",
    "PhoneNumberBlocksResource",
    "AsyncPhoneNumberBlocksResource",
    "PhoneNumberBlocksResourceWithRawResponse",
    "AsyncPhoneNumberBlocksResourceWithRawResponse",
    "PhoneNumberBlocksResourceWithStreamingResponse",
    "AsyncPhoneNumberBlocksResourceWithStreamingResponse",
    "PhoneNumberCampaignsResource",
    "AsyncPhoneNumberCampaignsResource",
    "PhoneNumberCampaignsResourceWithRawResponse",
    "AsyncPhoneNumberCampaignsResourceWithRawResponse",
    "PhoneNumberCampaignsResourceWithStreamingResponse",
    "AsyncPhoneNumberCampaignsResourceWithStreamingResponse",
    "PhoneNumbersResource",
    "AsyncPhoneNumbersResource",
    "PhoneNumbersResourceWithRawResponse",
    "AsyncPhoneNumbersResourceWithRawResponse",
    "PhoneNumbersResourceWithStreamingResponse",
    "AsyncPhoneNumbersResourceWithStreamingResponse",
    "PhoneNumbersRegulatoryRequirementsResource",
    "AsyncPhoneNumbersRegulatoryRequirementsResource",
    "PhoneNumbersRegulatoryRequirementsResourceWithRawResponse",
    "AsyncPhoneNumbersRegulatoryRequirementsResourceWithRawResponse",
    "PhoneNumbersRegulatoryRequirementsResourceWithStreamingResponse",
    "AsyncPhoneNumbersRegulatoryRequirementsResourceWithStreamingResponse",
    "PortabilityChecksResource",
    "AsyncPortabilityChecksResource",
    "PortabilityChecksResourceWithRawResponse",
    "AsyncPortabilityChecksResourceWithRawResponse",
    "PortabilityChecksResourceWithStreamingResponse",
    "AsyncPortabilityChecksResourceWithStreamingResponse",
    "PortingResource",
    "AsyncPortingResource",
    "PortingResourceWithRawResponse",
    "AsyncPortingResourceWithRawResponse",
    "PortingResourceWithStreamingResponse",
    "AsyncPortingResourceWithStreamingResponse",
    "PortingOrdersResource",
    "AsyncPortingOrdersResource",
    "PortingOrdersResourceWithRawResponse",
    "AsyncPortingOrdersResourceWithRawResponse",
    "PortingOrdersResourceWithStreamingResponse",
    "AsyncPortingOrdersResourceWithStreamingResponse",
    "PortingPhoneNumbersResource",
    "AsyncPortingPhoneNumbersResource",
    "PortingPhoneNumbersResourceWithRawResponse",
    "AsyncPortingPhoneNumbersResourceWithRawResponse",
    "PortingPhoneNumbersResourceWithStreamingResponse",
    "AsyncPortingPhoneNumbersResourceWithStreamingResponse",
    "PortoutsResource",
    "AsyncPortoutsResource",
    "PortoutsResourceWithRawResponse",
    "AsyncPortoutsResourceWithRawResponse",
    "PortoutsResourceWithStreamingResponse",
    "AsyncPortoutsResourceWithStreamingResponse",
    "PrivateWirelessGatewaysResource",
    "AsyncPrivateWirelessGatewaysResource",
    "PrivateWirelessGatewaysResourceWithRawResponse",
    "AsyncPrivateWirelessGatewaysResourceWithRawResponse",
    "PrivateWirelessGatewaysResourceWithStreamingResponse",
    "AsyncPrivateWirelessGatewaysResourceWithStreamingResponse",
    "PublicInternetGatewaysResource",
    "AsyncPublicInternetGatewaysResource",
    "PublicInternetGatewaysResourceWithRawResponse",
    "AsyncPublicInternetGatewaysResourceWithRawResponse",
    "PublicInternetGatewaysResourceWithStreamingResponse",
    "AsyncPublicInternetGatewaysResourceWithStreamingResponse",
    "QueuesResource",
    "AsyncQueuesResource",
    "QueuesResourceWithRawResponse",
    "AsyncQueuesResourceWithRawResponse",
    "QueuesResourceWithStreamingResponse",
    "AsyncQueuesResourceWithStreamingResponse",
    "RecordingTranscriptionsResource",
    "AsyncRecordingTranscriptionsResource",
    "RecordingTranscriptionsResourceWithRawResponse",
    "AsyncRecordingTranscriptionsResourceWithRawResponse",
    "RecordingTranscriptionsResourceWithStreamingResponse",
    "AsyncRecordingTranscriptionsResourceWithStreamingResponse",
    "RecordingsResource",
    "AsyncRecordingsResource",
    "RecordingsResourceWithRawResponse",
    "AsyncRecordingsResourceWithRawResponse",
    "RecordingsResourceWithStreamingResponse",
    "AsyncRecordingsResourceWithStreamingResponse",
    "RegionsResource",
    "AsyncRegionsResource",
    "RegionsResourceWithRawResponse",
    "AsyncRegionsResourceWithRawResponse",
    "RegionsResourceWithStreamingResponse",
    "AsyncRegionsResourceWithStreamingResponse",
    "RegulatoryRequirementsResource",
    "AsyncRegulatoryRequirementsResource",
    "RegulatoryRequirementsResourceWithRawResponse",
    "AsyncRegulatoryRequirementsResourceWithRawResponse",
    "RegulatoryRequirementsResourceWithStreamingResponse",
    "AsyncRegulatoryRequirementsResourceWithStreamingResponse",
    "ReportsResource",
    "AsyncReportsResource",
    "ReportsResourceWithRawResponse",
    "AsyncReportsResourceWithRawResponse",
    "ReportsResourceWithStreamingResponse",
    "AsyncReportsResourceWithStreamingResponse",
    "RequirementGroupsResource",
    "AsyncRequirementGroupsResource",
    "RequirementGroupsResourceWithRawResponse",
    "AsyncRequirementGroupsResourceWithRawResponse",
    "RequirementGroupsResourceWithStreamingResponse",
    "AsyncRequirementGroupsResourceWithStreamingResponse",
    "RequirementTypesResource",
    "AsyncRequirementTypesResource",
    "RequirementTypesResourceWithRawResponse",
    "AsyncRequirementTypesResourceWithRawResponse",
    "RequirementTypesResourceWithStreamingResponse",
    "AsyncRequirementTypesResourceWithStreamingResponse",
    "RequirementsResource",
    "AsyncRequirementsResource",
    "RequirementsResourceWithRawResponse",
    "AsyncRequirementsResourceWithRawResponse",
    "RequirementsResourceWithStreamingResponse",
    "AsyncRequirementsResourceWithStreamingResponse",
    "RoomCompositionsResource",
    "AsyncRoomCompositionsResource",
    "RoomCompositionsResourceWithRawResponse",
    "AsyncRoomCompositionsResourceWithRawResponse",
    "RoomCompositionsResourceWithStreamingResponse",
    "AsyncRoomCompositionsResourceWithStreamingResponse",
    "RoomParticipantsResource",
    "AsyncRoomParticipantsResource",
    "RoomParticipantsResourceWithRawResponse",
    "AsyncRoomParticipantsResourceWithRawResponse",
    "RoomParticipantsResourceWithStreamingResponse",
    "AsyncRoomParticipantsResourceWithStreamingResponse",
    "RoomRecordingsResource",
    "AsyncRoomRecordingsResource",
    "RoomRecordingsResourceWithRawResponse",
    "AsyncRoomRecordingsResourceWithRawResponse",
    "RoomRecordingsResourceWithStreamingResponse",
    "AsyncRoomRecordingsResourceWithStreamingResponse",
    "RoomsResource",
    "AsyncRoomsResource",
    "RoomsResourceWithRawResponse",
    "AsyncRoomsResourceWithRawResponse",
    "RoomsResourceWithStreamingResponse",
    "AsyncRoomsResourceWithStreamingResponse",
    "SetiResource",
    "AsyncSetiResource",
    "SetiResourceWithRawResponse",
    "AsyncSetiResourceWithRawResponse",
    "SetiResourceWithStreamingResponse",
    "AsyncSetiResourceWithStreamingResponse",
    "ShortCodesResource",
    "AsyncShortCodesResource",
    "ShortCodesResourceWithRawResponse",
    "AsyncShortCodesResourceWithRawResponse",
    "ShortCodesResourceWithStreamingResponse",
    "AsyncShortCodesResourceWithStreamingResponse",
    "SimCardDataUsageNotificationsResource",
    "AsyncSimCardDataUsageNotificationsResource",
    "SimCardDataUsageNotificationsResourceWithRawResponse",
    "AsyncSimCardDataUsageNotificationsResourceWithRawResponse",
    "SimCardDataUsageNotificationsResourceWithStreamingResponse",
    "AsyncSimCardDataUsageNotificationsResourceWithStreamingResponse",
    "SimCardGroupsResource",
    "AsyncSimCardGroupsResource",
    "SimCardGroupsResourceWithRawResponse",
    "AsyncSimCardGroupsResourceWithRawResponse",
    "SimCardGroupsResourceWithStreamingResponse",
    "AsyncSimCardGroupsResourceWithStreamingResponse",
    "SimCardOrderPreviewResource",
    "AsyncSimCardOrderPreviewResource",
    "SimCardOrderPreviewResourceWithRawResponse",
    "AsyncSimCardOrderPreviewResourceWithRawResponse",
    "SimCardOrderPreviewResourceWithStreamingResponse",
    "AsyncSimCardOrderPreviewResourceWithStreamingResponse",
    "SimCardOrdersResource",
    "AsyncSimCardOrdersResource",
    "SimCardOrdersResourceWithRawResponse",
    "AsyncSimCardOrdersResourceWithRawResponse",
    "SimCardOrdersResourceWithStreamingResponse",
    "AsyncSimCardOrdersResourceWithStreamingResponse",
    "SimCardsResource",
    "AsyncSimCardsResource",
    "SimCardsResourceWithRawResponse",
    "AsyncSimCardsResourceWithRawResponse",
    "SimCardsResourceWithStreamingResponse",
    "AsyncSimCardsResourceWithStreamingResponse",
    "SiprecConnectorsResource",
    "AsyncSiprecConnectorsResource",
    "SiprecConnectorsResourceWithRawResponse",
    "AsyncSiprecConnectorsResourceWithRawResponse",
    "SiprecConnectorsResourceWithStreamingResponse",
    "AsyncSiprecConnectorsResourceWithStreamingResponse",
    "StorageResource",
    "AsyncStorageResource",
    "StorageResourceWithRawResponse",
    "AsyncStorageResourceWithRawResponse",
    "StorageResourceWithStreamingResponse",
    "AsyncStorageResourceWithStreamingResponse",
    "SubNumberOrdersResource",
    "AsyncSubNumberOrdersResource",
    "SubNumberOrdersResourceWithRawResponse",
    "AsyncSubNumberOrdersResourceWithRawResponse",
    "SubNumberOrdersResourceWithStreamingResponse",
    "AsyncSubNumberOrdersResourceWithStreamingResponse",
    "SubNumberOrdersReportResource",
    "AsyncSubNumberOrdersReportResource",
    "SubNumberOrdersReportResourceWithRawResponse",
    "AsyncSubNumberOrdersReportResourceWithRawResponse",
    "SubNumberOrdersReportResourceWithStreamingResponse",
    "AsyncSubNumberOrdersReportResourceWithStreamingResponse",
    "TelephonyCredentialsResource",
    "AsyncTelephonyCredentialsResource",
    "TelephonyCredentialsResourceWithRawResponse",
    "AsyncTelephonyCredentialsResourceWithRawResponse",
    "TelephonyCredentialsResourceWithStreamingResponse",
    "AsyncTelephonyCredentialsResourceWithStreamingResponse",
    "TexmlResource",
    "AsyncTexmlResource",
    "TexmlResourceWithRawResponse",
    "AsyncTexmlResourceWithRawResponse",
    "TexmlResourceWithStreamingResponse",
    "AsyncTexmlResourceWithStreamingResponse",
    "TexmlApplicationsResource",
    "AsyncTexmlApplicationsResource",
    "TexmlApplicationsResourceWithRawResponse",
    "AsyncTexmlApplicationsResourceWithRawResponse",
    "TexmlApplicationsResourceWithStreamingResponse",
    "AsyncTexmlApplicationsResourceWithStreamingResponse",
    "TextToSpeechResource",
    "AsyncTextToSpeechResource",
    "TextToSpeechResourceWithRawResponse",
    "AsyncTextToSpeechResourceWithRawResponse",
    "TextToSpeechResourceWithStreamingResponse",
    "AsyncTextToSpeechResourceWithStreamingResponse",
    "UsageReportsResource",
    "AsyncUsageReportsResource",
    "UsageReportsResourceWithRawResponse",
    "AsyncUsageReportsResourceWithRawResponse",
    "UsageReportsResourceWithStreamingResponse",
    "AsyncUsageReportsResourceWithStreamingResponse",
    "UserAddressesResource",
    "AsyncUserAddressesResource",
    "UserAddressesResourceWithRawResponse",
    "AsyncUserAddressesResourceWithRawResponse",
    "UserAddressesResourceWithStreamingResponse",
    "AsyncUserAddressesResourceWithStreamingResponse",
    "UserTagsResource",
    "AsyncUserTagsResource",
    "UserTagsResourceWithRawResponse",
    "AsyncUserTagsResourceWithRawResponse",
    "UserTagsResourceWithStreamingResponse",
    "AsyncUserTagsResourceWithStreamingResponse",
    "VerificationsResource",
    "AsyncVerificationsResource",
    "VerificationsResourceWithRawResponse",
    "AsyncVerificationsResourceWithRawResponse",
    "VerificationsResourceWithStreamingResponse",
    "AsyncVerificationsResourceWithStreamingResponse",
    "VerifiedNumbersResource",
    "AsyncVerifiedNumbersResource",
    "VerifiedNumbersResourceWithRawResponse",
    "AsyncVerifiedNumbersResourceWithRawResponse",
    "VerifiedNumbersResourceWithStreamingResponse",
    "AsyncVerifiedNumbersResourceWithStreamingResponse",
    "VerifyProfilesResource",
    "AsyncVerifyProfilesResource",
    "VerifyProfilesResourceWithRawResponse",
    "AsyncVerifyProfilesResourceWithRawResponse",
    "VerifyProfilesResourceWithStreamingResponse",
    "AsyncVerifyProfilesResourceWithStreamingResponse",
    "VirtualCrossConnectsResource",
    "AsyncVirtualCrossConnectsResource",
    "VirtualCrossConnectsResourceWithRawResponse",
    "AsyncVirtualCrossConnectsResourceWithRawResponse",
    "VirtualCrossConnectsResourceWithStreamingResponse",
    "AsyncVirtualCrossConnectsResourceWithStreamingResponse",
    "VirtualCrossConnectsCoverageResource",
    "AsyncVirtualCrossConnectsCoverageResource",
    "VirtualCrossConnectsCoverageResourceWithRawResponse",
    "AsyncVirtualCrossConnectsCoverageResourceWithRawResponse",
    "VirtualCrossConnectsCoverageResourceWithStreamingResponse",
    "AsyncVirtualCrossConnectsCoverageResourceWithStreamingResponse",
    "WebhookDeliveriesResource",
    "AsyncWebhookDeliveriesResource",
    "WebhookDeliveriesResourceWithRawResponse",
    "AsyncWebhookDeliveriesResourceWithRawResponse",
    "WebhookDeliveriesResourceWithStreamingResponse",
    "AsyncWebhookDeliveriesResourceWithStreamingResponse",
    "WireguardInterfacesResource",
    "AsyncWireguardInterfacesResource",
    "WireguardInterfacesResourceWithRawResponse",
    "AsyncWireguardInterfacesResourceWithRawResponse",
    "WireguardInterfacesResourceWithStreamingResponse",
    "AsyncWireguardInterfacesResourceWithStreamingResponse",
    "WireguardPeersResource",
    "AsyncWireguardPeersResource",
    "WireguardPeersResourceWithRawResponse",
    "AsyncWireguardPeersResourceWithRawResponse",
    "WireguardPeersResourceWithStreamingResponse",
    "AsyncWireguardPeersResourceWithStreamingResponse",
    "WirelessResource",
    "AsyncWirelessResource",
    "WirelessResourceWithRawResponse",
    "AsyncWirelessResourceWithRawResponse",
    "WirelessResourceWithStreamingResponse",
    "AsyncWirelessResourceWithStreamingResponse",
    "WirelessBlocklistValuesResource",
    "AsyncWirelessBlocklistValuesResource",
    "WirelessBlocklistValuesResourceWithRawResponse",
    "AsyncWirelessBlocklistValuesResourceWithRawResponse",
    "WirelessBlocklistValuesResourceWithStreamingResponse",
    "AsyncWirelessBlocklistValuesResourceWithStreamingResponse",
    "WirelessBlocklistsResource",
    "AsyncWirelessBlocklistsResource",
    "WirelessBlocklistsResourceWithRawResponse",
    "AsyncWirelessBlocklistsResourceWithRawResponse",
    "WirelessBlocklistsResourceWithStreamingResponse",
    "AsyncWirelessBlocklistsResourceWithStreamingResponse",
    "PartnerCampaignsResource",
    "AsyncPartnerCampaignsResource",
    "PartnerCampaignsResourceWithRawResponse",
    "AsyncPartnerCampaignsResourceWithRawResponse",
    "PartnerCampaignsResourceWithStreamingResponse",
    "AsyncPartnerCampaignsResourceWithStreamingResponse",
    "WellKnownResource",
    "AsyncWellKnownResource",
    "WellKnownResourceWithRawResponse",
    "AsyncWellKnownResourceWithRawResponse",
    "WellKnownResourceWithStreamingResponse",
    "AsyncWellKnownResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ...types.ai import chat_create_completion_params
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["ChatResource", "AsyncChatResource"]


class ChatResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return ChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return ChatResourceWithStreamingResponse(self)

    def create_completion(
        self,
        *,
        messages: Iterable[chat_create_completion_params.Message],
        api_key_ref: str | Omit = omit,
        best_of: int | Omit = omit,
        early_stopping: bool | Omit = omit,
        frequency_penalty: float | Omit = omit,
        guided_choice: SequenceNotStr[str] | Omit = omit,
        guided_json: Dict[str, object] | Omit = omit,
        guided_regex: str | Omit = omit,
        length_penalty: float | Omit = omit,
        logprobs: bool | Omit = omit,
        max_tokens: int | Omit = omit,
        min_p: float | Omit = omit,
        model: str | Omit = omit,
        n: float | Omit = omit,
        presence_penalty: float | Omit = omit,
        response_format: chat_create_completion_params.ResponseFormat | Omit = omit,
        stream: bool | Omit = omit,
        temperature: float | Omit = omit,
        tool_choice: Literal["none", "auto", "required"] | Omit = omit,
        tools: Iterable[chat_create_completion_params.Tool] | Omit = omit,
        top_logprobs: int | Omit = omit,
        top_p: float | Omit = omit,
        use_beam_search: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Chat with a language model.

        This endpoint is consistent with the
        [OpenAI Chat Completions API](https://platform.openai.com/docs/api-reference/chat)
        and may be used with the OpenAI JS or Python SDK.

        Args:
          messages: A list of the previous chat messages for context.

          api_key_ref: If you are using an external inference provider like xAI or OpenAI, this field
              allows you to pass along a reference to your API key. After creating an
              [integration secret](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
              for you API key, pass the secret's `identifier` in this field.

          best_of: This is used with `use_beam_search` to determine how many candidate beams to
              explore.

          early_stopping: This is used with `use_beam_search`. If `true`, generation stops as soon as
              there are `best_of` complete candidates; if `false`, a heuristic is applied and
              the generation stops when is it very unlikely to find better candidates.

          frequency_penalty: Higher values will penalize the model from repeating the same output tokens.

          guided_choice: If specified, the output will be exactly one of the choices.

          guided_json: Must be a valid JSON schema. If specified, the output will follow the JSON
              schema.

          guided_regex: If specified, the output will follow the regex pattern.

          length_penalty: This is used with `use_beam_search` to prefer shorter or longer completions.

          logprobs: Whether to return log probabilities of the output tokens or not. If true,
              returns the log probabilities of each output token returned in the `content` of
              `message`.

          max_tokens: Maximum number of completion tokens the model should generate.

          min_p: This is an alternative to `top_p` that
              [many prefer](https://github.com/huggingface/transformers/issues/27670). Must be
              in [0, 1].

          model: The language model to chat with. If you are optimizing for speed + price, try
              `meta-llama/Meta-Llama-3.1-8B-Instruct`. For quality, try
              `meta-llama/Meta-Llama-3.1-70B-Instruct`. Or explore our
              [LLM Library](https://telnyx.com/products/llm-library).

          n: This will return multiple choices for you instead of a single chat completion.

          presence_penalty: Higher values will penalize the model from repeating the same output tokens.

          response_format: Use this is you want to guarantee a JSON output without defining a schema. For
              control over the schema, use `guided_json`.

          stream: Whether or not to stream data-only server-sent events as they become available.

          temperature: Adjusts the "creativity" of the model. Lower values make the model more
              deterministic and repetitive, while higher values make the model more random and
              creative.

          tools: The `function` tool type follows the same schema as the
              [OpenAI Chat Completions API](https://platform.openai.com/docs/api-reference/chat).
              The `retrieval` tool type is unique to Telnyx. You may pass a list of
              [embedded storage buckets](https://developers.telnyx.com/api/inference/inference-embedding/post-embedding)
              for retrieval-augmented generation.

          top_logprobs: This is used with `logprobs`. An integer between 0 and 20 specifying the number
              of most likely tokens to return at each token position, each with an associated
              log probability.

          top_p: An alternative or complement to `temperature`. This adjusts how many of the top
              possibilities to consider.

          use_beam_search: Setting this to `true` will allow the model to
              [explore more completion options](https://huggingface.co/blog/how-to-generate#beam-search).
              This is not supported by OpenAI.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/ai/chat/completions",
            body=maybe_transform(
                {
                    "messages": messages,
                    "api_key_ref": api_key_ref,
                    "best_of": best_of,
                    "early_stopping": early_stopping,
                    "frequency_penalty": frequency_penalty,
                    "guided_choice": guided_choice,
                    "guided_json": guided_json,
                    "guided_regex": guided_regex,
                    "length_penalty": length_penalty,
                    "logprobs": logprobs,
                    "max_tokens": max_tokens,
                    "min_p": min_p,
                    "model": model,
                    "n": n,
                    "presence_penalty": presence_penalty,
                    "response_format": response_format,
                    "stream": stream,
                    "temperature": temperature,
                    "tool_choice": tool_choice,
                    "tools": tools,
                    "top_logprobs": top_logprobs,
                    "top_p": top_p,
                    "use_beam_search": use_beam_search,
                },
                chat_create_completion_params.ChatCreateCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncChatResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncChatResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncChatResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncChatResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncChatResourceWithStreamingResponse(self)

    async def create_completion(
        self,
        *,
        messages: Iterable[chat_create_completion_params.Message],
        api_key_ref: str | Omit = omit,
        best_of: int | Omit = omit,
        early_stopping: bool | Omit = omit,
        frequency_penalty: float | Omit = omit,
        guided_choice: SequenceNotStr[str] | Omit = omit,
        guided_json: Dict[str, object] | Omit = omit,
        guided_regex: str | Omit = omit,
        length_penalty: float | Omit = omit,
        logprobs: bool | Omit = omit,
        max_tokens: int | Omit = omit,
        min_p: float | Omit = omit,
        model: str | Omit = omit,
        n: float | Omit = omit,
        presence_penalty: float | Omit = omit,
        response_format: chat_create_completion_params.ResponseFormat | Omit = omit,
        stream: bool | Omit = omit,
        temperature: float | Omit = omit,
        tool_choice: Literal["none", "auto", "required"] | Omit = omit,
        tools: Iterable[chat_create_completion_params.Tool] | Omit = omit,
        top_logprobs: int | Omit = omit,
        top_p: float | Omit = omit,
        use_beam_search: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """Chat with a language model.

        This endpoint is consistent with the
        [OpenAI Chat Completions API](https://platform.openai.com/docs/api-reference/chat)
        and may be used with the OpenAI JS or Python SDK.

        Args:
          messages: A list of the previous chat messages for context.

          api_key_ref: If you are using an external inference provider like xAI or OpenAI, this field
              allows you to pass along a reference to your API key. After creating an
              [integration secret](https://developers.telnyx.com/api/secrets-manager/integration-secrets/create-integration-secret)
              for you API key, pass the secret's `identifier` in this field.

          best_of: This is used with `use_beam_search` to determine how many candidate beams to
              explore.

          early_stopping: This is used with `use_beam_search`. If `true`, generation stops as soon as
              there are `best_of` complete candidates; if `false`, a heuristic is applied and
              the generation stops when is it very unlikely to find better candidates.

          frequency_penalty: Higher values will penalize the model from repeating the same output tokens.

          guided_choice: If specified, the output will be exactly one of the choices.

          guided_json: Must be a valid JSON schema. If specified, the output will follow the JSON
              schema.

          guided_regex: If specified, the output will follow the regex pattern.

          length_penalty: This is used with `use_beam_search` to prefer shorter or longer completions.

          logprobs: Whether to return log probabilities of the output tokens or not. If true,
              returns the log probabilities of each output token returned in the `content` of
              `message`.

          max_tokens: Maximum number of completion tokens the model should generate.

          min_p: This is an alternative to `top_p` that
              [many prefer](https://github.com/huggingface/transformers/issues/27670). Must be
              in [0, 1].

          model: The language model to chat with. If you are optimizing for speed + price, try
              `meta-llama/Meta-Llama-3.1-8B-Instruct`. For quality, try
              `meta-llama/Meta-Llama-3.1-70B-Instruct`. Or explore our
              [LLM Library](https://telnyx.com/products/llm-library).

          n: This will return multiple choices for you instead of a single chat completion.

          presence_penalty: Higher values will penalize the model from repeating the same output tokens.

          response_format: Use this is you want to guarantee a JSON output without defining a schema. For
              control over the schema, use `guided_json`.

          stream: Whether or not to stream data-only server-sent events as they become available.

          temperature: Adjusts the "creativity" of the model. Lower values make the model more
              deterministic and repetitive, while higher values make the model more random and
              creative.

          tools: The `function` tool type follows the same schema as the
              [OpenAI Chat Completions API](https://platform.openai.com/docs/api-reference/chat).
              The `retrieval` tool type is unique to Telnyx. You may pass a list of
              [embedded storage buckets](https://developers.telnyx.com/api/inference/inference-embedding/post-embedding)
              for retrieval-augmented generation.

          top_logprobs: This is used with `logprobs`. An integer between 0 and 20 specifying the number
              of most likely tokens to return at each token position, each with an associated
              log probability.

          top_p: An alternative or complement to `temperature`. This adjusts how many of the top
              possibilities to consider.

          use_beam_search: Setting this to `true` will allow the model to
              [explore more completion options](https://huggingface.co/blog/how-to-generate#beam-search).
              This is not supported by OpenAI.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/ai/chat/completions",
            body=await async_maybe_transform(
                {
                    "messages": messages,
                    "api_key_ref": api_key_ref,
                    "best_of": best_of,
                    "early_stopping": early_stopping,
                    "frequency_penalty": frequency_penalty,
                    "guided_choice": guided_choice,
                    "guided_json": guided_json,
                    "guided_regex": guided_regex,
                    "length_penalty": length_penalty,
                    "logprobs": logprobs,
                    "max_tokens": max_tokens,
                    "min_p": min_p,
                    "model": model,
                    "n": n,
                    "presence_penalty": presence_penalty,
                    "response_format": response_format,
                    "stream": stream,
                    "temperature": temperature,
                    "tool_choice": tool_choice,
                    "tools": tools,
                    "top_logprobs": top_logprobs,
                    "top_p": top_p,
                    "use_beam_search": use_beam_search,
                },
                chat_create_completion_params.ChatCreateCompletionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class ChatResourceWithRawResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.create_completion = to_raw_response_wrapper(
            chat.create_completion,
        )


class AsyncChatResourceWithRawResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.create_completion = async_to_raw_response_wrapper(
            chat.create_completion,
        )


class ChatResourceWithStreamingResponse:
    def __init__(self, chat: ChatResource) -> None:
        self._chat = chat

        self.create_completion = to_streamed_response_wrapper(
            chat.create_completion,
        )


class AsyncChatResourceWithStreamingResponse:
    def __init__(self, chat: AsyncChatResource) -> None:
        self._chat = chat

        self.create_completion = async_to_streamed_response_wrapper(
            chat.create_completion,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from .._models import BaseModel
from .pagination_meta import PaginationMeta

__all__ = ["PortingOrderRetrieveRequirementsResponse", "Data", "DataRequirementType"]


class DataRequirementType(BaseModel):
    id: Optional[str] = None
    """Identifies the requirement type"""

    acceptance_criteria: Optional[Dict[str, object]] = None
    """The acceptance criteria for the requirement type"""

    description: Optional[str] = None
    """A description of the requirement type"""

    example: Optional[str] = None
    """An example of the requirement type"""

    name: Optional[str] = None
    """The name of the requirement type"""

    type: Optional[str] = None
    """The type of the requirement type"""


class Data(BaseModel):
    field_type: Optional[Literal["document", "textual"]] = None
    """Type of value expected on field_value field"""

    field_value: Optional[str] = None
    """Identifies the document that satisfies this requirement"""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    requirement_status: Optional[str] = None
    """Status of the requirement"""

    requirement_type: Optional[DataRequirementType] = None
    """Identifies the requirement type that meets this requirement"""


class PortingOrderRetrieveRequirementsResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .job import Job
from ..._models import BaseModel
from ..pagination_meta import PaginationMeta

__all__ = ["JobListResponse"]


class JobListResponse(BaseModel):
    data: Optional[List[Job]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .wdr_report import WdrReport

__all__ = ["DetailRecordsReportDeleteResponse"]


class DetailRecordsReportDeleteResponse(BaseModel):
    data: Optional[WdrReport] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from ....._models import BaseModel

__all__ = ["MdrUsageReportResponseLegacy"]


class MdrUsageReportResponseLegacy(BaseModel):
    id: Optional[str] = None
    """Identifies the resource"""

    aggregation_type: Optional[int] = None
    """Aggregation type: No aggregation = 0, By Messaging Profile = 1, By Tags = 2"""

    connections: Optional[List[int]] = None

    created_at: Optional[datetime] = None

    end_time: Optional[datetime] = None

    profiles: Optional[List[str]] = None
    """List of messaging profile IDs"""

    record_type: Optional[str] = None

    report_url: Optional[str] = None

    result: Optional[object] = None

    start_time: Optional[datetime] = None

    status: Optional[int] = None
    """Status of the report (Pending = 1, Complete = 2, Failed = 3, Expired = 4)"""

    updated_at: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["TexmlApplicationListParams", "Filter", "Page"]


class TexmlApplicationListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[outbound_voice_profile_id], filter[friendly_name]
    """

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    sort: Literal["created_at", "friendly_name", "active"]
    """Specifies the sort order for results.

    By default sorting direction is ascending. To have the results sorted in
    descending order add the <code> -</code> prefix.<br/><br/> That is: <ul>

      <li>
        <code>friendly_name</code>: sorts the result by the
        <code>friendly_name</code> field in ascending order.
      </li>

      <li>
        <code>-friendly_name</code>: sorts the result by the
        <code>friendly_name</code> field in descending order.
      </li>
    </ul> <br/> If not given, results are sorted by <code>created_at</code> in descending order.
    """


class Filter(TypedDict, total=False):
    friendly_name: str
    """
    If present, applications with <code>friendly_name</code> containing the given
    value will be returned. Matching is not case-sensitive. Requires at least three
    characters.
    """

    outbound_voice_profile_id: str
    """Identifies the associated outbound voice profile."""


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["ActionUnholdParams"]


class ActionUnholdParams(TypedDict, total=False):
    call_control_ids: Required[SequenceNotStr[str]]
    """List of unique identifiers and tokens for controlling the call.

    Enter each call control ID to be unheld.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import datetime
from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo
from .conversation_channel_type import ConversationChannelType

__all__ = ["ScheduledEventListParams", "Page"]


class ScheduledEventListParams(TypedDict, total=False):
    conversation_channel: ConversationChannelType

    from_date: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    to_date: Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]


class Page(TypedDict, total=False):
    number: int

    size: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel
from .pagination_meta import PaginationMeta

__all__ = ["ConferenceListParticipantsResponse", "Data", "DataConference"]


class DataConference(BaseModel):
    id: Optional[str] = None
    """Uniquely identifies the conference"""

    name: Optional[str] = None
    """Name of the conference"""


class Data(BaseModel):
    id: str
    """Uniquely identifies the participant"""

    call_control_id: str
    """Call Control ID associated with the partiipant of the conference"""

    call_leg_id: str
    """Uniquely identifies the call leg associated with the participant"""

    conference: DataConference
    """Info about the conference that the participant is in"""

    created_at: str
    """ISO 8601 formatted date of when the participant was created"""

    end_conference_on_exit: bool
    """
    Whether the conference will end and all remaining participants be hung up after
    the participant leaves the conference.
    """

    muted: bool
    """Whether the participant is muted."""

    on_hold: bool
    """Whether the participant is put on_hold."""

    record_type: Literal["participant"]

    soft_end_conference_on_exit: bool
    """Whether the conference will end after the participant leaves the conference."""

    status: Literal["joining", "joined", "left"]
    """
    The status of the participant with respect to the lifecycle within the
    conference
    """

    updated_at: str
    """ISO 8601 formatted date of when the participant was last updated"""

    whisper_call_control_ids: List[str]
    """Array of unique call_control_ids the participant can whisper to.."""


class ConferenceListParticipantsResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .billing_group import BillingGroup

__all__ = ["BillingGroupRetrieveResponse"]


class BillingGroupRetrieveResponse(BaseModel):
    data: Optional[BillingGroup] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from ..._models import BaseModel
from ..pagination_meta import PaginationMeta

__all__ = ["AdditionalDocumentListResponse", "Data"]


class Data(BaseModel):
    id: Optional[str] = None
    """Uniquely identifies this additional document"""

    content_type: Optional[str] = None
    """The content type of the related document."""

    created_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was created."""

    document_id: Optional[str] = None
    """Identifies the associated document"""

    document_type: Optional[Literal["loa", "invoice", "csr", "other"]] = None
    """Identifies the type of additional document"""

    filename: Optional[str] = None
    """The filename of the related document."""

    porting_order_id: Optional[str] = None
    """Identifies the associated porting order"""

    record_type: Optional[str] = None
    """Identifies the type of the resource."""

    updated_at: Optional[datetime] = None
    """ISO 8601 formatted date indicating when the resource was updated."""


class AdditionalDocumentListResponse(BaseModel):
    data: Optional[List[Data]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CampaignStatusUpdateWebhookEvent"]


class CampaignStatusUpdateWebhookEvent(BaseModel):
    brand_id: Optional[str] = FieldInfo(alias="brandId", default=None)
    """Brand ID associated with the campaign."""

    campaign_id: Optional[str] = FieldInfo(alias="campaignId", default=None)
    """The ID of the campaign."""

    create_date: Optional[str] = FieldInfo(alias="createDate", default=None)
    """Unix timestamp when campaign was created."""

    csp_id: Optional[str] = FieldInfo(alias="cspId", default=None)
    """Alphanumeric identifier of the CSP associated with this campaign."""

    is_t_mobile_registered: Optional[bool] = FieldInfo(alias="isTMobileRegistered", default=None)
    """Indicates whether the campaign is registered with T-Mobile."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["JobListParams", "Filter", "Page"]


class JobListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style). Originally: filter[type]"""

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    sort: Literal["created_at"]
    """Specifies the sort order for results.

    If not given, results are sorted by created_at in descending order.
    """


class Filter(TypedDict, total=False):
    type: Literal["update_emergency_settings", "delete_phone_numbers", "update_phone_numbers"]
    """Identifies the type of the background job."""


class Page(TypedDict, total=False):
    number: int
    """The page number to load"""

    size: int
    """The size of the page"""
